// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
import * as FieldsAPI from "./fields.mjs";
import { Fields } from "./fields.mjs";
import * as JobsAPI from "./jobs.mjs";
import { Jobs } from "./jobs.mjs";
export class Datasets extends APIResource {
    constructor() {
        super(...arguments);
        this.fields = new FieldsAPI.Fields(this._client);
        this.jobs = new JobsAPI.Jobs(this._client);
    }
}
Datasets.Fields = Fields;
Datasets.Jobs = Jobs;
//# sourceMappingURL=datasets.mjs.map