// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../../../../../resource';
import * as LogsAPI from './logs';
import { LogGetParams, LogGetResponse, Logs } from './logs';

export class History extends APIResource {
  logs: LogsAPI.Logs = new LogsAPI.Logs(this._client);
}

History.Logs = Logs;

export declare namespace History {
  export { Logs as Logs, type LogGetResponse as LogGetResponse, type LogGetParams as LogGetParams };
}
