"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.TargetIndustries = void 0;
const resource_1 = require("../../../resource.js");
class TargetIndustries extends resource_1.APIResource {
    /**
     * Lists all target industries
     *
     * @example
     * ```ts
     * const targetIndustries =
     *   await client.cloudforceOne.threatEvents.targetIndustries.list(
     *     { account_id: 'account_id' },
     *   );
     * ```
     */
    list(params, options) {
        const { account_id } = params;
        return this._client.get(`/accounts/${account_id}/cloudforce-one/events/targetIndustries`, options);
    }
}
exports.TargetIndustries = TargetIndustries;
//# sourceMappingURL=target-industries.js.map