"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Slots = exports.Settings = exports.NetworkInterconnects = exports.Interconnects = exports.CNIs = void 0;
var cnis_1 = require("./cnis.js");
Object.defineProperty(exports, "CNIs", { enumerable: true, get: function () { return cnis_1.CNIs; } });
var interconnects_1 = require("./interconnects.js");
Object.defineProperty(exports, "Interconnects", { enumerable: true, get: function () { return interconnects_1.Interconnects; } });
var network_interconnects_1 = require("./network-interconnects.js");
Object.defineProperty(exports, "NetworkInterconnects", { enumerable: true, get: function () { return network_interconnects_1.NetworkInterconnects; } });
var settings_1 = require("./settings.js");
Object.defineProperty(exports, "Settings", { enumerable: true, get: function () { return settings_1.Settings; } });
var slots_1 = require("./slots.js");
Object.defineProperty(exports, "Slots", { enumerable: true, get: function () { return slots_1.Slots; } });
//# sourceMappingURL=index.js.map