// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
export class Miscategorizations extends APIResource {
    /**
     * Allows you to submit requests to change a domain’s category.
     *
     * @example
     * ```ts
     * const miscategorization =
     *   await client.intel.miscategorizations.create({
     *     account_id: '023e105f4ecef8ad9ca31a8372d0c353',
     *   });
     * ```
     */
    create(params, options) {
        const { account_id, ...body } = params;
        return this._client.post(`/accounts/${account_id}/intel/miscategorization`, { body, ...options });
    }
}
//# sourceMappingURL=miscategorizations.mjs.map