// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as IndexesAPI from "./indexes/indexes.mjs";
import { CreateIndicesSinglePage, Indexes, } from "./indexes/indexes.mjs";
export class Vectorize extends APIResource {
    constructor() {
        super(...arguments);
        this.indexes = new IndexesAPI.Indexes(this._client);
    }
}
Vectorize.Indexes = Indexes;
Vectorize.CreateIndicesSinglePage = CreateIndicesSinglePage;
//# sourceMappingURL=vectorize.mjs.map