"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Variants = exports.SmartTieredCache = exports.RegionalTieredCacheResource = exports.CacheReserveResource = exports.Cache = void 0;
var cache_1 = require("./cache.js");
Object.defineProperty(exports, "Cache", { enumerable: true, get: function () { return cache_1.Cache; } });
var cache_reserve_1 = require("./cache-reserve.js");
Object.defineProperty(exports, "CacheReserveResource", { enumerable: true, get: function () { return cache_reserve_1.CacheReserveResource; } });
var regional_tiered_cache_1 = require("./regional-tiered-cache.js");
Object.defineProperty(exports, "RegionalTieredCacheResource", { enumerable: true, get: function () { return regional_tiered_cache_1.RegionalTieredCacheResource; } });
var smart_tiered_cache_1 = require("./smart-tiered-cache.js");
Object.defineProperty(exports, "SmartTieredCache", { enumerable: true, get: function () { return smart_tiered_cache_1.SmartTieredCache; } });
var variants_1 = require("./variants.js");
Object.defineProperty(exports, "Variants", { enumerable: true, get: function () { return variants_1.Variants; } });
//# sourceMappingURL=index.js.map