// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as HostnamesAPI from "./hostnames/hostnames.mjs";
import { Hostnames, HostnamesSinglePage, } from "./hostnames/hostnames.mjs";
export class Web3 extends APIResource {
    constructor() {
        super(...arguments);
        this.hostnames = new HostnamesAPI.Hostnames(this._client);
    }
}
Web3.Hostnames = Hostnames;
Web3.HostnamesSinglePage = HostnamesSinglePage;
//# sourceMappingURL=web3.mjs.map