import { APIResource } from "../../../resource.js";
import * as TimeseriesGroupsAPI from "./timeseries-groups.js";
import { TimeseriesGroupUserAgentParams, TimeseriesGroupUserAgentResponse, TimeseriesGroups } from "./timeseries-groups.js";
import * as ToMarkdownAPI from "./to-markdown.js";
import { ToMarkdown, ToMarkdownCreateParams, ToMarkdownCreateResponse, ToMarkdownCreateResponsesSinglePage } from "./to-markdown.js";
import * as BotsAPI from "./bots/bots.js";
import { Bots } from "./bots/bots.js";
import * as InferenceAPI from "./inference/inference.js";
import { Inference } from "./inference/inference.js";
export declare class AI extends APIResource {
    toMarkdown: ToMarkdownAPI.ToMarkdown;
    inference: InferenceAPI.Inference;
    bots: BotsAPI.Bots;
    timeseriesGroups: TimeseriesGroupsAPI.TimeseriesGroups;
}
export declare namespace AI {
    export { ToMarkdown as ToMarkdown, type ToMarkdownCreateResponse as ToMarkdownCreateResponse, ToMarkdownCreateResponsesSinglePage as ToMarkdownCreateResponsesSinglePage, type ToMarkdownCreateParams as ToMarkdownCreateParams, };
    export { Inference as Inference };
    export { Bots as Bots };
    export { TimeseriesGroups as TimeseriesGroups, type TimeseriesGroupUserAgentResponse as TimeseriesGroupUserAgentResponse, type TimeseriesGroupUserAgentParams as TimeseriesGroupUserAgentParams, };
}
//# sourceMappingURL=ai.d.ts.map