"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Policies = exports.SettingsPoliciesSinglePage = exports.FallbackDomainsSinglePage = exports.SplitTunnelIncludesSinglePage = exports.SplitTunnelExcludesSinglePage = exports.Default = exports.Custom = void 0;
var index_1 = require("./custom/index.js");
Object.defineProperty(exports, "Custom", { enumerable: true, get: function () { return index_1.Custom; } });
var index_2 = require("./default/index.js");
Object.defineProperty(exports, "Default", { enumerable: true, get: function () { return index_2.Default; } });
var policies_1 = require("./policies.js");
Object.defineProperty(exports, "SplitTunnelExcludesSinglePage", { enumerable: true, get: function () { return policies_1.SplitTunnelExcludesSinglePage; } });
Object.defineProperty(exports, "SplitTunnelIncludesSinglePage", { enumerable: true, get: function () { return policies_1.SplitTunnelIncludesSinglePage; } });
Object.defineProperty(exports, "FallbackDomainsSinglePage", { enumerable: true, get: function () { return policies_1.FallbackDomainsSinglePage; } });
Object.defineProperty(exports, "SettingsPoliciesSinglePage", { enumerable: true, get: function () { return policies_1.SettingsPoliciesSinglePage; } });
Object.defineProperty(exports, "Policies", { enumerable: true, get: function () { return policies_1.Policies; } });
//# sourceMappingURL=index.js.map