// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
import * as IssueTypesAPI from "./issue-types.mjs";
import { IssueTypeGetResponsesSinglePage, IssueTypes, } from "./issue-types.mjs";
import * as IssuesAPI from "./issues.mjs";
import { IssueListResponsesV4PagePagination, Issues, } from "./issues.mjs";
export class AttackSurfaceReport extends APIResource {
    constructor() {
        super(...arguments);
        this.issueTypes = new IssueTypesAPI.IssueTypes(this._client);
        this.issues = new IssuesAPI.Issues(this._client);
    }
}
AttackSurfaceReport.IssueTypes = IssueTypes;
AttackSurfaceReport.IssueTypeGetResponsesSinglePage = IssueTypeGetResponsesSinglePage;
AttackSurfaceReport.Issues = Issues;
AttackSurfaceReport.IssueListResponsesV4PagePagination = IssueListResponsesV4PagePagination;
//# sourceMappingURL=attack-surface-report.mjs.map