import { APIResource } from "../../../../../resource.js";
import * as LogsAPI from "./logs.js";
import { LogGetParams, LogGetResponse, Logs } from "./logs.js";
export declare class History extends APIResource {
    logs: LogsAPI.Logs;
}
export declare namespace History {
    export { Logs as Logs, type LogGetResponse as LogGetResponse, type LogGetParams as LogGetParams };
}
//# sourceMappingURL=history.d.ts.map