// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
export class Matches extends APIResource {
}
//# sourceMappingURL=matches.mjs.map