"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Hostnames = exports.HostnameUpdateResponsesSinglePage = exports.Certificates = exports.CertificateListResponsesSinglePage = void 0;
var certificates_1 = require("./certificates.js");
Object.defineProperty(exports, "CertificateListResponsesSinglePage", { enumerable: true, get: function () { return certificates_1.CertificateListResponsesSinglePage; } });
Object.defineProperty(exports, "Certificates", { enumerable: true, get: function () { return certificates_1.Certificates; } });
var hostnames_1 = require("./hostnames.js");
Object.defineProperty(exports, "HostnameUpdateResponsesSinglePage", { enumerable: true, get: function () { return hostnames_1.HostnameUpdateResponsesSinglePage; } });
Object.defineProperty(exports, "Hostnames", { enumerable: true, get: function () { return hostnames_1.Hostnames; } });
//# sourceMappingURL=index.js.map