import { APIResource } from "../../resource.js";
import * as CNIsAPI from "./cnis.js";
import { CNICreateParams, CNICreateResponse, CNIDeleteParams, CNIGetParams, CNIGetResponse, CNIListParams, CNIListResponse, CNIUpdateParams, CNIUpdateResponse, CNIs } from "./cnis.js";
import * as InterconnectsAPI from "./interconnects.js";
import { InterconnectCreateParams, InterconnectCreateResponse, InterconnectDeleteParams, InterconnectGetParams, InterconnectGetResponse, InterconnectLOAParams, InterconnectListParams, InterconnectListResponse, InterconnectStatusParams, InterconnectStatusResponse, Interconnects } from "./interconnects.js";
import * as SettingsAPI from "./settings.js";
import { SettingGetParams, SettingGetResponse, SettingUpdateParams, SettingUpdateResponse, Settings } from "./settings.js";
import * as SlotsAPI from "./slots.js";
import { SlotGetParams, SlotGetResponse, SlotListParams, SlotListResponse, Slots } from "./slots.js";
export declare class NetworkInterconnects extends APIResource {
    cnis: CNIsAPI.CNIs;
    interconnects: InterconnectsAPI.Interconnects;
    settings: SettingsAPI.Settings;
    slots: SlotsAPI.Slots;
}
export declare namespace NetworkInterconnects {
    export { CNIs as CNIs, type CNICreateResponse as CNICreateResponse, type CNIUpdateResponse as CNIUpdateResponse, type CNIListResponse as CNIListResponse, type CNIGetResponse as CNIGetResponse, type CNICreateParams as CNICreateParams, type CNIUpdateParams as CNIUpdateParams, type CNIListParams as CNIListParams, type CNIDeleteParams as CNIDeleteParams, type CNIGetParams as CNIGetParams, };
    export { Interconnects as Interconnects, type InterconnectCreateResponse as InterconnectCreateResponse, type InterconnectListResponse as InterconnectListResponse, type InterconnectGetResponse as InterconnectGetResponse, type InterconnectStatusResponse as InterconnectStatusResponse, type InterconnectCreateParams as InterconnectCreateParams, type InterconnectListParams as InterconnectListParams, type InterconnectDeleteParams as InterconnectDeleteParams, type InterconnectGetParams as InterconnectGetParams, type InterconnectLOAParams as InterconnectLOAParams, type InterconnectStatusParams as InterconnectStatusParams, };
    export { Settings as Settings, type SettingUpdateResponse as SettingUpdateResponse, type SettingGetResponse as SettingGetResponse, type SettingUpdateParams as SettingUpdateParams, type SettingGetParams as SettingGetParams, };
    export { Slots as Slots, type SlotListResponse as SlotListResponse, type SlotGetResponse as SlotGetResponse, type SlotListParams as SlotListParams, type SlotGetParams as SlotGetParams, };
}
//# sourceMappingURL=network-interconnects.d.ts.map