// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as TotalTLSAPI from "./total-tls.mjs";
import { TotalTLS, } from "./total-tls.mjs";
export class ACM extends APIResource {
    constructor() {
        super(...arguments);
        this.totalTLS = new TotalTLSAPI.TotalTLS(this._client);
    }
}
ACM.TotalTLS = TotalTLS;
//# sourceMappingURL=acm.mjs.map