// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../../resource';
import * as WidgetsAPI from './widgets';
import {
  Widget,
  WidgetCreateParams,
  WidgetDeleteParams,
  WidgetDomain,
  WidgetGetParams,
  WidgetListParams,
  WidgetListResponse,
  WidgetListResponsesV4PagePaginationArray,
  WidgetRotateSecretParams,
  WidgetUpdateParams,
  Widgets,
} from './widgets';

export class Turnstile extends APIResource {
  widgets: WidgetsAPI.Widgets = new WidgetsAPI.Widgets(this._client);
}

Turnstile.Widgets = Widgets;
Turnstile.WidgetListResponsesV4PagePaginationArray = WidgetListResponsesV4PagePaginationArray;

export declare namespace Turnstile {
  export {
    Widgets as Widgets,
    type Widget as Widget,
    type WidgetDomain as WidgetDomain,
    type WidgetListResponse as WidgetListResponse,
    WidgetListResponsesV4PagePaginationArray as WidgetListResponsesV4PagePaginationArray,
    type WidgetCreateParams as WidgetCreateParams,
    type WidgetUpdateParams as WidgetUpdateParams,
    type WidgetListParams as WidgetListParams,
    type WidgetDeleteParams as WidgetDeleteParams,
    type WidgetGetParams as WidgetGetParams,
    type WidgetRotateSecretParams as WidgetRotateSecretParams,
  };
}
