// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as ConfigsAPI from "./configs.mjs";
import { Configs, } from "./configs.mjs";
import { SinglePage } from "../../pagination.mjs";
export class HyperdriveResource extends APIResource {
    constructor() {
        super(...arguments);
        this.configs = new ConfigsAPI.Configs(this._client);
    }
}
export class HyperdrivesSinglePage extends SinglePage {
}
HyperdriveResource.Configs = Configs;
//# sourceMappingURL=hyperdrive.mjs.map