import { APIResource } from "../resource.js";
import * as Core from "../core.js";
export declare class DCVDelegation extends APIResource {
    /**
     * Retrieve the account and zone specific unique identifier used as part of the
     * CNAME target for DCV Delegation.
     */
    get(params: DCVDelegationGetParams, options?: Core.RequestOptions): Core.APIPromise<DCVDelegationUUID>;
}
export interface DCVDelegationUUID {
    /**
     * The DCV Delegation unique identifier.
     */
    uuid?: string;
}
export interface DCVDelegationGetParams {
    /**
     * Identifier.
     */
    zone_id: string;
}
export declare namespace DCVDelegation {
    export { type DCVDelegationUUID as DCVDelegationUUID, type DCVDelegationGetParams as DCVDelegationGetParams, };
}
//# sourceMappingURL=dcv-delegation.d.ts.map