// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
import * as TelemetryAPI from "./telemetry.mjs";
import { Telemetry, TelemetryKeysResponsesSinglePage, TelemetryValuesResponsesSinglePage, } from "./telemetry.mjs";
export class Observability extends APIResource {
    constructor() {
        super(...arguments);
        this.telemetry = new TelemetryAPI.Telemetry(this._client);
    }
}
Observability.Telemetry = Telemetry;
Observability.TelemetryKeysResponsesSinglePage = TelemetryKeysResponsesSinglePage;
Observability.TelemetryValuesResponsesSinglePage = TelemetryValuesResponsesSinglePage;
//# sourceMappingURL=observability.mjs.map