import { APIResource } from "../../../../resource.js";
import * as CustomAPI from "./custom.js";
import { Custom, CustomCreateParams, CustomCreateResponse, CustomDeleteParams, CustomDeleteResponse, CustomGetParams, CustomGetResponse, CustomListParams, CustomListResponse, CustomUpdateParams, CustomUpdateResponse } from "./custom.js";
import * as ManagedAPI from "./managed.js";
import { Managed, ManagedListParams, ManagedListResponse, ManagedUpdateParams, ManagedUpdateResponse } from "./managed.js";
export declare class Domains extends APIResource {
    custom: CustomAPI.Custom;
    managed: ManagedAPI.Managed;
}
export declare namespace Domains {
    export { Custom as Custom, type CustomCreateResponse as CustomCreateResponse, type CustomUpdateResponse as CustomUpdateResponse, type CustomListResponse as CustomListResponse, type CustomDeleteResponse as CustomDeleteResponse, type CustomGetResponse as CustomGetResponse, type CustomCreateParams as CustomCreateParams, type CustomUpdateParams as CustomUpdateParams, type CustomListParams as CustomListParams, type CustomDeleteParams as CustomDeleteParams, type CustomGetParams as CustomGetParams, };
    export { Managed as Managed, type ManagedUpdateResponse as ManagedUpdateResponse, type ManagedListResponse as ManagedListResponse, type ManagedUpdateParams as ManagedUpdateParams, type ManagedListParams as ManagedListParams, };
}
//# sourceMappingURL=domains.d.ts.map