"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.TemporaryCredentials = exports.SuperSlurper = exports.R2 = exports.Buckets = void 0;
var index_1 = require("./buckets/index.js");
Object.defineProperty(exports, "Buckets", { enumerable: true, get: function () { return index_1.Buckets; } });
var r2_1 = require("./r2.js");
Object.defineProperty(exports, "R2", { enumerable: true, get: function () { return r2_1.R2; } });
var index_2 = require("./super-slurper/index.js");
Object.defineProperty(exports, "SuperSlurper", { enumerable: true, get: function () { return index_2.SuperSlurper; } });
var temporary_credentials_1 = require("./temporary-credentials.js");
Object.defineProperty(exports, "TemporaryCredentials", { enumerable: true, get: function () { return temporary_credentials_1.TemporaryCredentials; } });
//# sourceMappingURL=index.js.map