"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.VirtualNetworks = exports.VirtualNetworksSinglePage = exports.Routes = exports.TeamnetsV4PagePaginationArray = exports.Subnets = exports.SubnetListResponsesV4PagePaginationArray = exports.Networks = void 0;
var networks_1 = require("./networks.js");
Object.defineProperty(exports, "Networks", { enumerable: true, get: function () { return networks_1.Networks; } });
var index_1 = require("./subnets/index.js");
Object.defineProperty(exports, "SubnetListResponsesV4PagePaginationArray", { enumerable: true, get: function () { return index_1.SubnetListResponsesV4PagePaginationArray; } });
Object.defineProperty(exports, "Subnets", { enumerable: true, get: function () { return index_1.Subnets; } });
var index_2 = require("./routes/index.js");
Object.defineProperty(exports, "TeamnetsV4PagePaginationArray", { enumerable: true, get: function () { return index_2.TeamnetsV4PagePaginationArray; } });
Object.defineProperty(exports, "Routes", { enumerable: true, get: function () { return index_2.Routes; } });
var virtual_networks_1 = require("./virtual-networks.js");
Object.defineProperty(exports, "VirtualNetworksSinglePage", { enumerable: true, get: function () { return virtual_networks_1.VirtualNetworksSinglePage; } });
Object.defineProperty(exports, "VirtualNetworks", { enumerable: true, get: function () { return virtual_networks_1.VirtualNetworks; } });
//# sourceMappingURL=index.js.map