export { AddressSpaces, type AddressSpaceUpdateResponse, type AddressSpaceListResponse, type AddressSpaceEditResponse, type AddressSpaceUpdateParams, type AddressSpaceListParams, type AddressSpaceEditParams, } from "./address-spaces.js";
export { OnRampListResponsesSinglePage, OnRamps, type OnRampCreateResponse, type OnRampUpdateResponse, type OnRampListResponse, type OnRampDeleteResponse, type OnRampApplyResponse, type OnRampEditResponse, type OnRampGetResponse, type OnRampPlanResponse, type OnRampCreateParams, type OnRampUpdateParams, type OnRampListParams, type OnRampDeleteParams, type OnRampApplyParams, type OnRampEditParams, type OnRampExportParams, type OnRampGetParams, type OnRampPlanParams, } from "./on-ramps.js";
//# sourceMappingURL=index.d.ts.map