import { APIResource } from "../../../resource.js";
import * as Layer3API from "./layer3/layer3.js";
import { Layer3, Layer3TimeseriesParams, Layer3TimeseriesResponse } from "./layer3/layer3.js";
import * as Layer7API from "./layer7/layer7.js";
import { Layer7, Layer7TimeseriesParams, Layer7TimeseriesResponse } from "./layer7/layer7.js";
export declare class Attacks extends APIResource {
    layer3: Layer3API.Layer3;
    layer7: Layer7API.Layer7;
}
export declare namespace Attacks {
    export { Layer3 as Layer3, type Layer3TimeseriesResponse as Layer3TimeseriesResponse, type Layer3TimeseriesParams as Layer3TimeseriesParams, };
    export { Layer7 as Layer7, type Layer7TimeseriesResponse as Layer7TimeseriesResponse, type Layer7TimeseriesParams as Layer7TimeseriesParams, };
}
//# sourceMappingURL=attacks.d.ts.map