import { APIResource } from "../../resource.js";
import * as SmartRoutingAPI from "./smart-routing.js";
import { SmartRouting, SmartRoutingEditParams, SmartRoutingEditResponse, SmartRoutingGetParams, SmartRoutingGetResponse } from "./smart-routing.js";
import * as TieredCachingAPI from "./tiered-caching.js";
import { TieredCaching, TieredCachingEditParams, TieredCachingEditResponse, TieredCachingGetParams, TieredCachingGetResponse } from "./tiered-caching.js";
export declare class Argo extends APIResource {
    smartRouting: SmartRoutingAPI.SmartRouting;
    tieredCaching: TieredCachingAPI.TieredCaching;
}
export declare namespace Argo {
    export { SmartRouting as SmartRouting, type SmartRoutingEditResponse as SmartRoutingEditResponse, type SmartRoutingGetResponse as SmartRoutingGetResponse, type SmartRoutingEditParams as SmartRoutingEditParams, type SmartRoutingGetParams as SmartRoutingGetParams, };
    export { TieredCaching as TieredCaching, type TieredCachingEditResponse as TieredCachingEditResponse, type TieredCachingGetResponse as TieredCachingGetResponse, type TieredCachingEditParams as TieredCachingEditParams, type TieredCachingGetParams as TieredCachingGetParams, };
}
//# sourceMappingURL=argo.d.ts.map