"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Outages = exports.Annotations = void 0;
var annotations_1 = require("./annotations.js");
Object.defineProperty(exports, "Annotations", { enumerable: true, get: function () { return annotations_1.Annotations; } });
var outages_1 = require("./outages.js");
Object.defineProperty(exports, "Outages", { enumerable: true, get: function () { return outages_1.Outages; } });
//# sourceMappingURL=index.js.map