import { APIResource } from "../../resource.js";
import * as Core from "../../core.js";
export declare class URLs extends APIResource {
    /**
     * Get Gateway URL
     *
     * @example
     * ```ts
     * const url = await client.aiGateway.urls.get(
     *   'my-gateway',
     *   'workers-ai',
     *   { account_id: '0d37909e38d3e99c29fa2cd343ac421a' },
     * );
     * ```
     */
    get(gatewayId: string, provider: string, params: URLGetParams, options?: Core.RequestOptions): Core.APIPromise<URLGetResponse>;
}
export type URLGetResponse = string;
export interface URLGetParams {
    account_id: string;
}
export declare namespace URLs {
    export { type URLGetResponse as URLGetResponse, type URLGetParams as URLGetParams };
}
//# sourceMappingURL=urls.d.ts.map