"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Integrations = exports.IntegrationsSinglePage = exports.Posture = exports.DevicePostureRulesSinglePage = void 0;
var posture_1 = require("./posture.js");
Object.defineProperty(exports, "DevicePostureRulesSinglePage", { enumerable: true, get: function () { return posture_1.DevicePostureRulesSinglePage; } });
Object.defineProperty(exports, "Posture", { enumerable: true, get: function () { return posture_1.Posture; } });
var integrations_1 = require("./integrations.js");
Object.defineProperty(exports, "IntegrationsSinglePage", { enumerable: true, get: function () { return integrations_1.IntegrationsSinglePage; } });
Object.defineProperty(exports, "Integrations", { enumerable: true, get: function () { return integrations_1.Integrations; } });
//# sourceMappingURL=index.js.map