// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../../../resource.mjs";
import * as LogsAPI from "./logs.mjs";
import { Logs } from "./logs.mjs";
export class History extends APIResource {
    constructor() {
        super(...arguments);
        this.logs = new LogsAPI.Logs(this._client);
    }
}
History.Logs = Logs;
//# sourceMappingURL=history.mjs.map