// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../../resource.mjs";
import * as GlobalWARPOverrideAPI from "./global-warp-override.mjs";
import { GlobalWARPOverride, } from "./global-warp-override.mjs";
export class Resilience extends APIResource {
    constructor() {
        super(...arguments);
        this.globalWARPOverride = new GlobalWARPOverrideAPI.GlobalWARPOverride(this._client);
    }
}
Resilience.GlobalWARPOverride = GlobalWARPOverride;
//# sourceMappingURL=resilience.mjs.map