// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

export {
  CatchAlls,
  type CatchAllAction,
  type CatchAllMatcher,
  type CatchAllUpdateResponse,
  type CatchAllGetResponse,
  type CatchAllUpdateParams,
  type CatchAllGetParams,
} from './catch-alls';
export {
  EmailRoutingRulesV4PagePaginationArray,
  Rules,
  type Action,
  type EmailRoutingRule,
  type Matcher,
  type RuleCreateParams,
  type RuleUpdateParams,
  type RuleListParams,
  type RuleDeleteParams,
  type RuleGetParams,
} from './rules';
