import { APIResource } from "../../resource.js";
import * as Core from "../../core.js";
import { type Response } from "../../_shims/index.js";
export declare class Content extends APIResource {
    /**
     * Snippet Content
     *
     * @example
     * ```ts
     * const content = await client.snippets.content.get(
     *   'snippet_name_01',
     *   { zone_id: '023e105f4ecef8ad9ca31a8372d0c353' },
     * );
     *
     * const data = await content.blob();
     * console.log(data);
     * ```
     */
    get(snippetName: string, params: ContentGetParams, options?: Core.RequestOptions): Core.APIPromise<Response>;
}
export interface ContentGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace Content {
    export { type ContentGetParams as ContentGetParams };
}
//# sourceMappingURL=content.d.ts.map