// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as HostnameAssociationsAPI from "./hostname-associations.mjs";
import { HostnameAssociations, } from "./hostname-associations.mjs";
export class CertificateAuthorities extends APIResource {
    constructor() {
        super(...arguments);
        this.hostnameAssociations = new HostnameAssociationsAPI.HostnameAssociations(this._client);
    }
}
CertificateAuthorities.HostnameAssociations = HostnameAssociations;
//# sourceMappingURL=certificate-authorities.mjs.map