// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
import * as HistoryAPI from "./history.mjs";
import { BillingHistoriesV4PagePaginationArray, History } from "./history.mjs";
import * as ProfileAPI from "./profile.mjs";
import { Profile } from "./profile.mjs";
export class Billing extends APIResource {
    constructor() {
        super(...arguments);
        this.history = new HistoryAPI.History(this._client);
        this.profile = new ProfileAPI.Profile(this._client);
    }
}
Billing.History = History;
Billing.BillingHistoriesV4PagePaginationArray = BillingHistoriesV4PagePaginationArray;
Billing.Profile = Profile;
//# sourceMappingURL=billing.mjs.map