// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

export { Advertisements, type Advertisement, type AdvertisementEditParams } from './advertisements';
export {
  MagicNetworkMonitoringRulesSinglePage,
  Rules,
  type MagicNetworkMonitoringRule,
  type RuleCreateParams,
  type RuleUpdateParams,
  type RuleListParams,
  type RuleDeleteParams,
  type RuleEditParams,
  type RuleGetParams,
} from './rules';
