import { APIResource } from "../../../resource.js";
import * as FallthroughAPI from "./fallthrough.js";
import { Fallthrough, FallthroughCreateParams, FallthroughCreateResponse } from "./fallthrough.js";
export declare class ExpressionTemplate extends APIResource {
    fallthrough: FallthroughAPI.Fallthrough;
}
export declare namespace ExpressionTemplate {
    export { Fallthrough as Fallthrough, type FallthroughCreateResponse as FallthroughCreateResponse, type FallthroughCreateParams as FallthroughCreateParams, };
}
//# sourceMappingURL=expression-template.d.ts.map