import { APIResource } from "../../resource.js";
import * as DomainsAPI from "./domains.js";
import { Domain, DomainGetParams, DomainGetResponse, DomainListParams, DomainUpdateParams, DomainUpdateResponse, Domains, DomainsSinglePage } from "./domains.js";
export declare class Registrar extends APIResource {
    domains: DomainsAPI.Domains;
}
export declare namespace Registrar {
    export { Domains as Domains, type Domain as Domain, type DomainUpdateResponse as DomainUpdateResponse, type DomainGetResponse as DomainGetResponse, DomainsSinglePage as DomainsSinglePage, type DomainUpdateParams as DomainUpdateParams, type DomainListParams as DomainListParams, type DomainGetParams as DomainGetParams, };
}
//# sourceMappingURL=registrar.d.ts.map