"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Pages = exports.Projects = exports.DeploymentsSinglePage = void 0;
var index_1 = require("./projects/index.js");
Object.defineProperty(exports, "DeploymentsSinglePage", { enumerable: true, get: function () { return index_1.DeploymentsSinglePage; } });
Object.defineProperty(exports, "Projects", { enumerable: true, get: function () { return index_1.Projects; } });
var pages_1 = require("./pages.js");
Object.defineProperty(exports, "Pages", { enumerable: true, get: function () { return pages_1.Pages; } });
//# sourceMappingURL=index.js.map