"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.LeakedCredentialChecks = exports.Detections = exports.DetectionListResponsesSinglePage = void 0;
var detections_1 = require("./detections.js");
Object.defineProperty(exports, "DetectionListResponsesSinglePage", { enumerable: true, get: function () { return detections_1.DetectionListResponsesSinglePage; } });
Object.defineProperty(exports, "Detections", { enumerable: true, get: function () { return detections_1.Detections; } });
var leaked_credential_checks_1 = require("./leaked-credential-checks.js");
Object.defineProperty(exports, "LeakedCredentialChecks", { enumerable: true, get: function () { return leaked_credential_checks_1.LeakedCredentialChecks; } });
//# sourceMappingURL=index.js.map