"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Namespaces = exports.NamespacesV4PagePaginationArray = exports.KV = void 0;
var kv_1 = require("./kv.js");
Object.defineProperty(exports, "KV", { enumerable: true, get: function () { return kv_1.KV; } });
var index_1 = require("./namespaces/index.js");
Object.defineProperty(exports, "NamespacesV4PagePaginationArray", { enumerable: true, get: function () { return index_1.NamespacesV4PagePaginationArray; } });
Object.defineProperty(exports, "Namespaces", { enumerable: true, get: function () { return index_1.Namespaces; } });
//# sourceMappingURL=index.js.map