import { APIResource } from "../../../resource.js";
import * as Core from "../../../core.js";
import * as ConfigsAPI from "./configs.js";
export declare class Full extends APIResource {
    /**
     * Lists default sampling, router IPs, warp devices, and rules for account.
     *
     * @example
     * ```ts
     * const configuration =
     *   await client.magicNetworkMonitoring.configs.full.get({
     *     account_id: '6f91088a406011ed95aed352566e8d4c',
     *   });
     * ```
     */
    get(params: FullGetParams, options?: Core.RequestOptions): Core.APIPromise<ConfigsAPI.Configuration>;
}
export interface FullGetParams {
    account_id: string;
}
export declare namespace Full {
    export { type FullGetParams as FullGetParams };
}
//# sourceMappingURL=full.d.ts.map