export { HTTPTests, type HTTPDetails, type HTTPTestGetParams } from "./http-tests.js";
export { Percentiles, type HTTPDetailsPercentiles, type TestStatOverTime, type PercentileGetParams, } from "./percentiles.js";
//# sourceMappingURL=index.d.ts.map