// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as AppsAPI from "./apps.mjs";
import { AppListResponsesV4PagePaginationArray, Apps, } from "./apps.mjs";
import * as AnalyticsAPI from "./analytics/analytics.mjs";
import { Analytics } from "./analytics/analytics.mjs";
export class Spectrum extends APIResource {
    constructor() {
        super(...arguments);
        this.analytics = new AnalyticsAPI.Analytics(this._client);
        this.apps = new AppsAPI.Apps(this._client);
    }
}
Spectrum.Analytics = Analytics;
Spectrum.Apps = Apps;
Spectrum.AppListResponsesV4PagePaginationArray = AppListResponsesV4PagePaginationArray;
//# sourceMappingURL=spectrum.mjs.map