"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Latest = void 0;
const resource_1 = require("../../../../resource.js");
class Latest extends resource_1.APIResource {
    /**
     * Get latest Snapshots
     *
     * @example
     * ```ts
     * const latests =
     *   await client.magicTransit.connectors.snapshots.latest.list(
     *     'connector_id',
     *     { account_id: '023e105f4ecef8ad9ca31a8372d0c353' },
     *   );
     * ```
     */
    list(connectorId, params, options) {
        const { account_id } = params;
        return this._client.get(`/accounts/${account_id}/magic/connectors/${connectorId}/telemetry/snapshots/latest`, options)._thenUnwrap((obj) => obj.result);
    }
}
exports.Latest = Latest;
//# sourceMappingURL=latest.js.map