"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Profile = void 0;
const resource_1 = require("../../../resource.js");
class Profile extends resource_1.APIResource {
    /**
     * Accesses your billing profile object.
     *
     * @deprecated
     */
    get(options) {
        return this._client.get('/user/billing/profile', options)._thenUnwrap((obj) => obj.result);
    }
}
exports.Profile = Profile;
//# sourceMappingURL=profile.js.map