"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.WorkersForPlatforms = exports.Dispatch = void 0;
var index_1 = require("./dispatch/index.js");
Object.defineProperty(exports, "Dispatch", { enumerable: true, get: function () { return index_1.Dispatch; } });
var workers_for_platforms_1 = require("./workers-for-platforms.js");
Object.defineProperty(exports, "WorkersForPlatforms", { enumerable: true, get: function () { return workers_for_platforms_1.WorkersForPlatforms; } });
//# sourceMappingURL=index.js.map