import { APIResource } from "../../../resource.js";
import * as Core from "../../../core.js";
export declare class Schema extends APIResource {
    /**
     * Get Model Schema
     */
    get(params: SchemaGetParams, options?: Core.RequestOptions): Core.APIPromise<SchemaGetResponse>;
}
export type SchemaGetResponse = unknown;
export interface SchemaGetParams {
    /**
     * Path param:
     */
    account_id: string;
    /**
     * Query param: Model Name
     */
    model: string;
}
export declare namespace Schema {
    export { type SchemaGetResponse as SchemaGetResponse, type SchemaGetParams as SchemaGetParams };
}
//# sourceMappingURL=schema.d.ts.map