import { APIResource } from "../../../../resource.js";
import * as ConfigAPI from "./config.js";
import { CmbConfig, Config, ConfigCreateParams, ConfigDeleteParams, ConfigDeleteResponse, ConfigGetParams } from "./config.js";
export declare class Cmb extends APIResource {
    config: ConfigAPI.Config;
}
export declare namespace Cmb {
    export { Config as Config, type CmbConfig as CmbConfig, type ConfigDeleteResponse as ConfigDeleteResponse, type ConfigCreateParams as ConfigCreateParams, type ConfigDeleteParams as ConfigDeleteParams, type ConfigGetParams as ConfigGetParams, };
}
//# sourceMappingURL=cmb.d.ts.map