"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Settings = exports.OriginTLSClientAuth = exports.Hostnames = exports.HostnameUpdateResponsesSinglePage = void 0;
var index_1 = require("./hostnames/index.js");
Object.defineProperty(exports, "HostnameUpdateResponsesSinglePage", { enumerable: true, get: function () { return index_1.HostnameUpdateResponsesSinglePage; } });
Object.defineProperty(exports, "Hostnames", { enumerable: true, get: function () { return index_1.Hostnames; } });
var origin_tls_client_auth_1 = require("./origin-tls-client-auth.js");
Object.defineProperty(exports, "OriginTLSClientAuth", { enumerable: true, get: function () { return origin_tls_client_auth_1.OriginTLSClientAuth; } });
var settings_1 = require("./settings.js");
Object.defineProperty(exports, "Settings", { enumerable: true, get: function () { return settings_1.Settings; } });
//# sourceMappingURL=index.js.map