import { APIResource } from "../../resource.js";
import * as ConfigsAPI from "./configs/configs.js";
import { ConfigCreateParams, ConfigDeleteParams, ConfigEditParams, ConfigGetParams, ConfigUpdateParams, Configs, Configuration } from "./configs/configs.js";
import * as RulesAPI from "./rules/rules.js";
import { MagicNetworkMonitoringRule, MagicNetworkMonitoringRulesSinglePage, RuleCreateParams, RuleDeleteParams, RuleEditParams, RuleGetParams, RuleListParams, RuleUpdateParams, Rules } from "./rules/rules.js";
import * as VPCFlowsAPI from "./vpc-flows/vpc-flows.js";
import { VPCFlows } from "./vpc-flows/vpc-flows.js";
export declare class MagicNetworkMonitoring extends APIResource {
    vpcFlows: VPCFlowsAPI.VPCFlows;
    configs: ConfigsAPI.Configs;
    rules: RulesAPI.Rules;
}
export declare namespace MagicNetworkMonitoring {
    export { VPCFlows as VPCFlows };
    export { Configs as Configs, type Configuration as Configuration, type ConfigCreateParams as ConfigCreateParams, type ConfigUpdateParams as ConfigUpdateParams, type ConfigDeleteParams as ConfigDeleteParams, type ConfigEditParams as ConfigEditParams, type ConfigGetParams as ConfigGetParams, };
    export { Rules as Rules, type MagicNetworkMonitoringRule as MagicNetworkMonitoringRule, MagicNetworkMonitoringRulesSinglePage as MagicNetworkMonitoringRulesSinglePage, type RuleCreateParams as RuleCreateParams, type RuleUpdateParams as RuleUpdateParams, type RuleListParams as RuleListParams, type RuleDeleteParams as RuleDeleteParams, type RuleEditParams as RuleEditParams, type RuleGetParams as RuleGetParams, };
}
//# sourceMappingURL=magic-network-monitoring.d.ts.map