"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Routes = exports.TeamnetsV4PagePaginationArray = exports.Networks = exports.IPs = void 0;
var ips_1 = require("./ips.js");
Object.defineProperty(exports, "IPs", { enumerable: true, get: function () { return ips_1.IPs; } });
var networks_1 = require("./networks.js");
Object.defineProperty(exports, "Networks", { enumerable: true, get: function () { return networks_1.Networks; } });
var routes_1 = require("./routes.js");
Object.defineProperty(exports, "TeamnetsV4PagePaginationArray", { enumerable: true, get: function () { return routes_1.TeamnetsV4PagePaginationArray; } });
Object.defineProperty(exports, "Routes", { enumerable: true, get: function () { return routes_1.Routes; } });
//# sourceMappingURL=index.js.map