"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Organizations = exports.DOH = void 0;
var doh_1 = require("./doh.js");
Object.defineProperty(exports, "DOH", { enumerable: true, get: function () { return doh_1.DOH; } });
var organizations_1 = require("./organizations.js");
Object.defineProperty(exports, "Organizations", { enumerable: true, get: function () { return organizations_1.Organizations; } });
//# sourceMappingURL=index.js.map