import { APIResource } from "../../../resource.js";
import * as Core from "../../../core.js";
export declare class Events extends APIResource {
    /**
     * Send event to instance
     */
    create(workflowName: string, instanceId: string, eventType: string, params: EventCreateParams, options?: Core.RequestOptions): Core.APIPromise<EventCreateResponse>;
}
export type EventCreateResponse = unknown;
export interface EventCreateParams {
    /**
     * Path param:
     */
    account_id: string;
    /**
     * Body param:
     */
    body?: unknown;
}
export declare namespace Events {
    export { type EventCreateResponse as EventCreateResponse, type EventCreateParams as EventCreateParams };
}
//# sourceMappingURL=events.d.ts.map