// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
import * as ZoneAPI from "./zone.mjs";
import { Zone } from "./zone.mjs";
import * as AccountAPI from "./account/account.mjs";
import { Account, } from "./account/account.mjs";
export class Settings extends APIResource {
    constructor() {
        super(...arguments);
        this.zone = new ZoneAPI.Zone(this._client);
        this.account = new AccountAPI.Account(this._client);
    }
}
Settings.Zone = Zone;
Settings.Account = Account;
//# sourceMappingURL=settings.mjs.map