import { APIResource } from "../../../resource.js";
import * as CertificatesAPI from "./certificates.js";
import { CertificateDeleteParams, CertificateDeleteResponse, CertificateUpdateParams, CertificateUpdateResponse, Certificates } from "./certificates.js";
export declare class CertificatePack extends APIResource {
    certificates: CertificatesAPI.Certificates;
}
export declare namespace CertificatePack {
    export { Certificates as Certificates, type CertificateUpdateResponse as CertificateUpdateResponse, type CertificateDeleteResponse as CertificateDeleteResponse, type CertificateUpdateParams as CertificateUpdateParams, type CertificateDeleteParams as CertificateDeleteParams, };
}
//# sourceMappingURL=certificate-pack.d.ts.map