// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
export class IndicatorTypes extends APIResource {
    /**
     * Lists all indicator types
     *
     * @example
     * ```ts
     * const indicatorTypes =
     *   await client.cloudforceOne.threatEvents.indicatorTypes.list(
     *     { account_id: 'account_id' },
     *   );
     * ```
     */
    list(params, options) {
        const { account_id } = params;
        return this._client.get(`/accounts/${account_id}/cloudforce-one/events/indicatorTypes`, options);
    }
}
//# sourceMappingURL=indicator-types.mjs.map