// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
import * as TLSAPI from "./tls.mjs";
import { TLS, TLSGetResponsesSinglePage, } from "./tls.mjs";
export class Settings extends APIResource {
    constructor() {
        super(...arguments);
        this.tls = new TLSAPI.TLS(this._client);
    }
}
Settings.TLS = TLS;
Settings.TLSGetResponsesSinglePage = TLSGetResponsesSinglePage;
//# sourceMappingURL=settings.mjs.map