"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Speed = exports.Quality = exports.IQI = void 0;
var iqi_1 = require("./iqi.js");
Object.defineProperty(exports, "IQI", { enumerable: true, get: function () { return iqi_1.IQI; } });
var quality_1 = require("./quality.js");
Object.defineProperty(exports, "Quality", { enumerable: true, get: function () { return quality_1.Quality; } });
var index_1 = require("./speed/index.js");
Object.defineProperty(exports, "Speed", { enumerable: true, get: function () { return index_1.Speed; } });
//# sourceMappingURL=index.js.map