import { APIResource } from "../../resource.js";
import * as Core from "../../core.js";
import * as ConfigAPI from "./config.js";
export declare class Default extends APIResource {
    /**
     * Gets default Zaraz configuration for a zone.
     *
     * @example
     * ```ts
     * const configuration = await client.zaraz.default.get({
     *   zone_id: '023e105f4ecef8ad9ca31a8372d0c353',
     * });
     * ```
     */
    get(params: DefaultGetParams, options?: Core.RequestOptions): Core.APIPromise<ConfigAPI.Configuration>;
}
export interface DefaultGetParams {
    /**
     * Identifier.
     */
    zone_id: string;
}
export declare namespace Default {
    export { type DefaultGetParams as DefaultGetParams };
}
//# sourceMappingURL=default.d.ts.map