import { APIResource } from "../../resource.js";
import * as SettingsAPI from "./settings/settings.js";
import { Settings } from "./settings/settings.js";
export declare class Hostnames extends APIResource {
    settings: SettingsAPI.Settings;
}
export declare namespace Hostnames {
    export { Settings as Settings };
}
//# sourceMappingURL=hostnames.d.ts.map