export { ConfigListResponsesSinglePage, Config, type ConfigCreateResponse, type ConfigListResponse, type ConfigDeleteResponse, type ConfigEditResponse, type ConfigCreateParams, type ConfigListParams, type ConfigDeleteParams, type ConfigEditParams, } from "./config.js";
export { Results, type ScanResult, type ResultGetResponse, type ResultGetParams } from "./results.js";
export { Scans } from "./scans.js";
//# sourceMappingURL=index.d.ts.map