// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as DatabaseAPI from "./database.mjs";
import { Database, DatabaseListResponsesV4PagePaginationArray, DatabaseRawResponsesSinglePage, QueryResultsSinglePage, } from "./database.mjs";
export class D1Resource extends APIResource {
    constructor() {
        super(...arguments);
        this.database = new DatabaseAPI.Database(this._client);
    }
}
D1Resource.Database = Database;
D1Resource.DatabaseListResponsesV4PagePaginationArray = DatabaseListResponsesV4PagePaginationArray;
D1Resource.QueryResultsSinglePage = QueryResultsSinglePage;
D1Resource.DatabaseRawResponsesSinglePage = DatabaseRawResponsesSinglePage;
//# sourceMappingURL=d1.mjs.map