// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
import * as NamespacesAPI from "./namespaces/namespaces.mjs";
import { NamespaceListResponsesSinglePage, Namespaces, } from "./namespaces/namespaces.mjs";
export class Dispatch extends APIResource {
    constructor() {
        super(...arguments);
        this.namespaces = new NamespacesAPI.Namespaces(this._client);
    }
}
Dispatch.Namespaces = Namespaces;
Dispatch.NamespaceListResponsesSinglePage = NamespaceListResponsesSinglePage;
//# sourceMappingURL=dispatch.mjs.map