import { APIResource } from "../../../resource.js";
import * as HistoryAPI from "./history.js";
import { BillingHistoriesV4PagePaginationArray, BillingHistory, History, HistoryListParams } from "./history.js";
import * as ProfileAPI from "./profile.js";
import { Profile, ProfileGetResponse } from "./profile.js";
export declare class Billing extends APIResource {
    history: HistoryAPI.History;
    profile: ProfileAPI.Profile;
}
export declare namespace Billing {
    export { History as History, type BillingHistory as BillingHistory, BillingHistoriesV4PagePaginationArray as BillingHistoriesV4PagePaginationArray, type HistoryListParams as HistoryListParams, };
    export { Profile as Profile, type ProfileGetResponse as ProfileGetResponse };
}
//# sourceMappingURL=billing.d.ts.map