import { APIResource } from "../../resource.js";
import * as PermissionGroupsAPI from "./permission-groups.js";
import { PermissionGroupGetParams, PermissionGroupGetResponse, PermissionGroupListParams, PermissionGroupListResponse, PermissionGroupListResponsesV4PagePaginationArray, PermissionGroups } from "./permission-groups.js";
import * as ResourceGroupsAPI from "./resource-groups.js";
import { ResourceGroupCreateParams, ResourceGroupCreateResponse, ResourceGroupDeleteParams, ResourceGroupDeleteResponse, ResourceGroupGetParams, ResourceGroupGetResponse, ResourceGroupListParams, ResourceGroupListResponse, ResourceGroupListResponsesV4PagePaginationArray, ResourceGroupUpdateParams, ResourceGroupUpdateResponse, ResourceGroups } from "./resource-groups.js";
import * as UserGroupsAPI from "./user-groups/user-groups.js";
import { UserGroupCreateParams, UserGroupCreateResponse, UserGroupDeleteParams, UserGroupDeleteResponse, UserGroupGetParams, UserGroupGetResponse, UserGroupListParams, UserGroupListResponse, UserGroupListResponsesV4PagePaginationArray, UserGroupUpdateParams, UserGroupUpdateResponse, UserGroups } from "./user-groups/user-groups.js";
export declare class IAM extends APIResource {
    permissionGroups: PermissionGroupsAPI.PermissionGroups;
    resourceGroups: ResourceGroupsAPI.ResourceGroups;
    userGroups: UserGroupsAPI.UserGroups;
}
export declare namespace IAM {
    export { PermissionGroups as PermissionGroups, type PermissionGroupListResponse as PermissionGroupListResponse, type PermissionGroupGetResponse as PermissionGroupGetResponse, PermissionGroupListResponsesV4PagePaginationArray as PermissionGroupListResponsesV4PagePaginationArray, type PermissionGroupListParams as PermissionGroupListParams, type PermissionGroupGetParams as PermissionGroupGetParams, };
    export { ResourceGroups as ResourceGroups, type ResourceGroupCreateResponse as ResourceGroupCreateResponse, type ResourceGroupUpdateResponse as ResourceGroupUpdateResponse, type ResourceGroupListResponse as ResourceGroupListResponse, type ResourceGroupDeleteResponse as ResourceGroupDeleteResponse, type ResourceGroupGetResponse as ResourceGroupGetResponse, ResourceGroupListResponsesV4PagePaginationArray as ResourceGroupListResponsesV4PagePaginationArray, type ResourceGroupCreateParams as ResourceGroupCreateParams, type ResourceGroupUpdateParams as ResourceGroupUpdateParams, type ResourceGroupListParams as ResourceGroupListParams, type ResourceGroupDeleteParams as ResourceGroupDeleteParams, type ResourceGroupGetParams as ResourceGroupGetParams, };
    export { UserGroups as UserGroups, type UserGroupCreateResponse as UserGroupCreateResponse, type UserGroupUpdateResponse as UserGroupUpdateResponse, type UserGroupListResponse as UserGroupListResponse, type UserGroupDeleteResponse as UserGroupDeleteResponse, type UserGroupGetResponse as UserGroupGetResponse, UserGroupListResponsesV4PagePaginationArray as UserGroupListResponsesV4PagePaginationArray, type UserGroupCreateParams as UserGroupCreateParams, type UserGroupUpdateParams as UserGroupUpdateParams, type UserGroupListParams as UserGroupListParams, type UserGroupDeleteParams as UserGroupDeleteParams, type UserGroupGetParams as UserGroupGetParams, };
}
//# sourceMappingURL=iam.d.ts.map