// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
import * as TopAPI from "./top.mjs";
import { Top } from "./top.mjs";
export class VerifiedBots extends APIResource {
    constructor() {
        super(...arguments);
        this.top = new TopAPI.Top(this._client);
    }
}
VerifiedBots.Top = Top;
//# sourceMappingURL=verified-bots.mjs.map