// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as SchemasAPI from "./schemas.mjs";
import { SchemaListResponsesV4PagePaginationArray, Schemas, } from "./schemas.mjs";
import * as SettingsAPI from "./settings/settings.mjs";
import { Settings, } from "./settings/settings.mjs";
export class SchemaValidation extends APIResource {
    constructor() {
        super(...arguments);
        this.schemas = new SchemasAPI.Schemas(this._client);
        this.settings = new SettingsAPI.Settings(this._client);
    }
}
SchemaValidation.Schemas = Schemas;
SchemaValidation.SchemaListResponsesV4PagePaginationArray = SchemaListResponsesV4PagePaginationArray;
SchemaValidation.Settings = Settings;
//# sourceMappingURL=schema-validation.mjs.map