"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.IPFSUniversalPaths = exports.Hostnames = exports.HostnamesSinglePage = void 0;
var hostnames_1 = require("./hostnames.js");
Object.defineProperty(exports, "HostnamesSinglePage", { enumerable: true, get: function () { return hostnames_1.HostnamesSinglePage; } });
Object.defineProperty(exports, "Hostnames", { enumerable: true, get: function () { return hostnames_1.Hostnames; } });
var index_1 = require("./ipfs-universal-paths/index.js");
Object.defineProperty(exports, "IPFSUniversalPaths", { enumerable: true, get: function () { return index_1.IPFSUniversalPaths; } });
//# sourceMappingURL=index.js.map