import { APIResource } from "../../../resource.js";
import * as Core from "../../../core.js";
import * as Shared from "../../shared.js";
export declare class Value extends APIResource {
    /**
     * Roll the token secret.
     *
     * @example
     * ```ts
     * const tokenValue = await client.user.tokens.value.update(
     *   'ed17574386854bf78a67040be0a770b0',
     *   {},
     * );
     * ```
     */
    update(tokenId: string, body: ValueUpdateParams, options?: Core.RequestOptions): Core.APIPromise<Shared.TokenValue>;
}
export type ValueUpdateParams = unknown;
export declare namespace Value {
    export { type ValueUpdateParams as ValueUpdateParams };
}
//# sourceMappingURL=value.d.ts.map