// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../../../../../resource';
import * as SummaryAPI from './summary';
import {
  Summary,
  SummaryModelParams,
  SummaryModelResponse,
  SummaryTaskParams,
  SummaryTaskResponse,
} from './summary';

export class TimeseriesGroups extends APIResource {
  summary: SummaryAPI.Summary = new SummaryAPI.Summary(this._client);
}

TimeseriesGroups.Summary = Summary;

export declare namespace TimeseriesGroups {
  export {
    Summary as Summary,
    type SummaryModelResponse as SummaryModelResponse,
    type SummaryTaskResponse as SummaryTaskResponse,
    type SummaryModelParams as SummaryModelParams,
    type SummaryTaskParams as SummaryTaskParams,
  };
}
