// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../../../../resource';
import * as UploadAPI from './upload';
import { Upload, UploadCreateParams, UploadCreateResponse } from './upload';

export class Assets extends APIResource {
  upload: UploadAPI.Upload = new UploadAPI.Upload(this._client);
}

Assets.Upload = Upload;

export declare namespace Assets {
  export {
    Upload as Upload,
    type UploadCreateResponse as UploadCreateResponse,
    type UploadCreateParams as UploadCreateParams,
  };
}
