"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Namespaces = exports.NamespaceListResponsesSinglePage = exports.Dispatch = void 0;
var dispatch_1 = require("./dispatch.js");
Object.defineProperty(exports, "Dispatch", { enumerable: true, get: function () { return dispatch_1.Dispatch; } });
var index_1 = require("./namespaces/index.js");
Object.defineProperty(exports, "NamespaceListResponsesSinglePage", { enumerable: true, get: function () { return index_1.NamespaceListResponsesSinglePage; } });
Object.defineProperty(exports, "Namespaces", { enumerable: true, get: function () { return index_1.Namespaces; } });
//# sourceMappingURL=index.js.map