// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
import * as TokensAPI from "./tokens.mjs";
import { Tokens } from "./tokens.mjs";
export class VPCFlows extends APIResource {
    constructor() {
        super(...arguments);
        this.tokens = new TokensAPI.Tokens(this._client);
    }
}
VPCFlows.Tokens = Tokens;
//# sourceMappingURL=vpc-flows.mjs.map