// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

export {
  AddressesV4PagePaginationArray,
  Addresses,
  type Address,
  type AddressCreateParams,
  type AddressListParams,
  type AddressDeleteParams,
  type AddressGetParams,
} from './addresses';
export {
  DNSRecordsSinglePage,
  DNS,
  type DNSRecord,
  type DNSGetResponse,
  type DNSCreateParams,
  type DNSDeleteParams,
  type DNSEditParams,
  type DNSGetParams,
} from './dns';
export { EmailRouting } from './email-routing';
export {
  EmailRoutingRulesV4PagePaginationArray,
  Rules,
  type Action,
  type EmailRoutingRule,
  type Matcher,
  type RuleCreateParams,
  type RuleUpdateParams,
  type RuleListParams,
  type RuleDeleteParams,
  type RuleGetParams,
} from './rules/index';
