"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Rules = exports.EmailRoutingRulesV4PagePaginationArray = exports.CatchAlls = void 0;
var catch_alls_1 = require("./catch-alls.js");
Object.defineProperty(exports, "CatchAlls", { enumerable: true, get: function () { return catch_alls_1.CatchAlls; } });
var rules_1 = require("./rules.js");
Object.defineProperty(exports, "EmailRoutingRulesV4PagePaginationArray", { enumerable: true, get: function () { return rules_1.EmailRoutingRulesV4PagePaginationArray; } });
Object.defineProperty(exports, "Rules", { enumerable: true, get: function () { return rules_1.Rules; } });
//# sourceMappingURL=index.js.map