import { APIResource } from "../../../../resource.js";
import * as GlobalWARPOverrideAPI from "./global-warp-override.js";
import { GlobalWARPOverride, GlobalWARPOverrideCreateParams, GlobalWARPOverrideCreateResponse, GlobalWARPOverrideGetParams, GlobalWARPOverrideGetResponse } from "./global-warp-override.js";
export declare class Resilience extends APIResource {
    globalWARPOverride: GlobalWARPOverrideAPI.GlobalWARPOverride;
}
export declare namespace Resilience {
    export { GlobalWARPOverride as GlobalWARPOverride, type GlobalWARPOverrideCreateResponse as GlobalWARPOverrideCreateResponse, type GlobalWARPOverrideGetResponse as GlobalWARPOverrideGetResponse, type GlobalWARPOverrideCreateParams as GlobalWARPOverrideCreateParams, type GlobalWARPOverrideGetParams as GlobalWARPOverrideGetParams, };
}
//# sourceMappingURL=resilience.d.ts.map