import { APIResource } from "../../resource.js";
import * as TotalTLSAPI from "./total-tls.js";
import { CertificateAuthority, TotalTLS, TotalTLSCreateParams, TotalTLSCreateResponse, TotalTLSGetParams, TotalTLSGetResponse } from "./total-tls.js";
export declare class ACM extends APIResource {
    totalTLS: TotalTLSAPI.TotalTLS;
}
export declare namespace ACM {
    export { TotalTLS as TotalTLS, type CertificateAuthority as CertificateAuthority, type TotalTLSCreateResponse as TotalTLSCreateResponse, type TotalTLSGetResponse as TotalTLSGetResponse, type TotalTLSCreateParams as TotalTLSCreateParams, type TotalTLSGetParams as TotalTLSGetParams, };
}
//# sourceMappingURL=acm.d.ts.map