"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResourceSharing = exports.Resources = exports.ResourceListResponsesV4PagePaginationArray = exports.Recipients = exports.RecipientListResponsesV4PagePaginationArray = void 0;
var recipients_1 = require("./recipients.js");
Object.defineProperty(exports, "RecipientListResponsesV4PagePaginationArray", { enumerable: true, get: function () { return recipients_1.RecipientListResponsesV4PagePaginationArray; } });
Object.defineProperty(exports, "Recipients", { enumerable: true, get: function () { return recipients_1.Recipients; } });
var resources_1 = require("./resources.js");
Object.defineProperty(exports, "ResourceListResponsesV4PagePaginationArray", { enumerable: true, get: function () { return resources_1.ResourceListResponsesV4PagePaginationArray; } });
Object.defineProperty(exports, "Resources", { enumerable: true, get: function () { return resources_1.Resources; } });
var resource_sharing_1 = require("./resource-sharing.js");
Object.defineProperty(exports, "ResourceSharing", { enumerable: true, get: function () { return resource_sharing_1.ResourceSharing; } });
//# sourceMappingURL=index.js.map