// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
import * as ASNAPI from "./asn.mjs";
import { ASN } from "./asn.mjs";
export class Configs extends APIResource {
    constructor() {
        super(...arguments);
        this.asn = new ASNAPI.ASN(this._client);
    }
}
Configs.ASN = ASN;
//# sourceMappingURL=configs.mjs.map