"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogoMatches = void 0;
const resource_1 = require("../../resource.js");
class LogoMatches extends resource_1.APIResource {
}
exports.LogoMatches = LogoMatches;
//# sourceMappingURL=logo-matches.js.map