"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServiceBindings = exports.ServiceBindingsSinglePage = exports.Prefixes = exports.PrefixesSinglePage = exports.Delegations = exports.DelegationsSinglePage = exports.BGPPrefixes = exports.BGPPrefixesSinglePage = exports.AdvertisementStatus = void 0;
var advertisement_status_1 = require("./advertisement-status.js");
Object.defineProperty(exports, "AdvertisementStatus", { enumerable: true, get: function () { return advertisement_status_1.AdvertisementStatus; } });
var bgp_prefixes_1 = require("./bgp-prefixes.js");
Object.defineProperty(exports, "BGPPrefixesSinglePage", { enumerable: true, get: function () { return bgp_prefixes_1.BGPPrefixesSinglePage; } });
Object.defineProperty(exports, "BGPPrefixes", { enumerable: true, get: function () { return bgp_prefixes_1.BGPPrefixes; } });
var delegations_1 = require("./delegations.js");
Object.defineProperty(exports, "DelegationsSinglePage", { enumerable: true, get: function () { return delegations_1.DelegationsSinglePage; } });
Object.defineProperty(exports, "Delegations", { enumerable: true, get: function () { return delegations_1.Delegations; } });
var prefixes_1 = require("./prefixes.js");
Object.defineProperty(exports, "PrefixesSinglePage", { enumerable: true, get: function () { return prefixes_1.PrefixesSinglePage; } });
Object.defineProperty(exports, "Prefixes", { enumerable: true, get: function () { return prefixes_1.Prefixes; } });
var service_bindings_1 = require("./service-bindings.js");
Object.defineProperty(exports, "ServiceBindingsSinglePage", { enumerable: true, get: function () { return service_bindings_1.ServiceBindingsSinglePage; } });
Object.defineProperty(exports, "ServiceBindings", { enumerable: true, get: function () { return service_bindings_1.ServiceBindings; } });
//# sourceMappingURL=index.js.map