"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MagicCloudNetworking = void 0;
const resource_1 = require("../../resource.js");
const CloudIntegrationsAPI = __importStar(require("./cloud-integrations.js"));
const cloud_integrations_1 = require("./cloud-integrations.js");
const ResourcesAPI = __importStar(require("./resources.js"));
const resources_1 = require("./resources.js");
const CatalogSyncsAPI = __importStar(require("./catalog-syncs/catalog-syncs.js"));
const catalog_syncs_1 = require("./catalog-syncs/catalog-syncs.js");
const OnRampsAPI = __importStar(require("./on-ramps/on-ramps.js"));
const on_ramps_1 = require("./on-ramps/on-ramps.js");
class MagicCloudNetworking extends resource_1.APIResource {
    constructor() {
        super(...arguments);
        this.catalogSyncs = new CatalogSyncsAPI.CatalogSyncs(this._client);
        this.onRamps = new OnRampsAPI.OnRamps(this._client);
        this.cloudIntegrations = new CloudIntegrationsAPI.CloudIntegrations(this._client);
        this.resources = new ResourcesAPI.Resources(this._client);
    }
}
exports.MagicCloudNetworking = MagicCloudNetworking;
MagicCloudNetworking.CatalogSyncs = catalog_syncs_1.CatalogSyncs;
MagicCloudNetworking.CatalogSyncListResponsesSinglePage = catalog_syncs_1.CatalogSyncListResponsesSinglePage;
MagicCloudNetworking.OnRamps = on_ramps_1.OnRamps;
MagicCloudNetworking.OnRampListResponsesSinglePage = on_ramps_1.OnRampListResponsesSinglePage;
MagicCloudNetworking.CloudIntegrations = cloud_integrations_1.CloudIntegrations;
MagicCloudNetworking.CloudIntegrationListResponsesSinglePage = cloud_integrations_1.CloudIntegrationListResponsesSinglePage;
MagicCloudNetworking.Resources = resources_1.Resources;
MagicCloudNetworking.ResourceListResponsesV4PagePaginationArray = resources_1.ResourceListResponsesV4PagePaginationArray;
//# sourceMappingURL=magic-cloud-networking.js.map