// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as ASNAPI from "./asn.mjs";
import { ASN, } from "./asn.mjs";
import * as ConfigsAPI from "./configs/configs.mjs";
import { Configs } from "./configs/configs.mjs";
export class BotnetFeed extends APIResource {
    constructor() {
        super(...arguments);
        this.asn = new ASNAPI.ASN(this._client);
        this.configs = new ConfigsAPI.Configs(this._client);
    }
}
BotnetFeed.ASN = ASN;
BotnetFeed.Configs = Configs;
//# sourceMappingURL=botnet-feed.mjs.map