// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../../../resource';
import * as ASNAPI from './asn';
import { ASN, ASNDeleteParams, ASNDeleteResponse, ASNGetParams, ASNGetResponse } from './asn';

export class Configs extends APIResource {
  asn: ASNAPI.ASN = new ASNAPI.ASN(this._client);
}

Configs.ASN = ASN;

export declare namespace Configs {
  export {
    ASN as ASN,
    type ASNDeleteResponse as ASNDeleteResponse,
    type ASNGetResponse as ASNGetResponse,
    type ASNDeleteParams as ASNDeleteParams,
    type ASNGetParams as ASNGetParams,
  };
}
