// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as ResponsesAPI from "./responses.mjs";
import { Responses } from "./responses.mjs";
import * as ScansAPI from "./scans.mjs";
import { Scans, } from "./scans.mjs";
export class URLScanner extends APIResource {
    constructor() {
        super(...arguments);
        this.responses = new ResponsesAPI.Responses(this._client);
        this.scans = new ScansAPI.Scans(this._client);
    }
}
URLScanner.Responses = Responses;
URLScanner.Scans = Scans;
//# sourceMappingURL=url-scanner.mjs.map