import { APIResource } from "../../../resource.js";
import * as RoutingAPI from "./routing/routing.js";
import { Routing } from "./routing/routing.js";
import * as SecurityAPI from "./security/security.js";
import { Security } from "./security/security.js";
export declare class Email extends APIResource {
    routing: RoutingAPI.Routing;
    security: SecurityAPI.Security;
}
export interface RadarEmailSeries {
    FAIL: Array<string>;
    NONE: Array<string>;
    PASS: Array<string>;
}
export interface RadarEmailSummary {
    /**
     * A numeric string.
     */
    FAIL: string;
    /**
     * A numeric string.
     */
    NONE: string;
    /**
     * A numeric string.
     */
    PASS: string;
}
export declare namespace Email {
    export { type RadarEmailSeries as RadarEmailSeries, type RadarEmailSummary as RadarEmailSummary };
    export { Routing as Routing };
    export { Security as Security };
}
//# sourceMappingURL=email.d.ts.map