// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as NamespacesAPI from "./namespaces/namespaces.mjs";
import { Namespaces, NamespacesV4PagePaginationArray, } from "./namespaces/namespaces.mjs";
export class KV extends APIResource {
    constructor() {
        super(...arguments);
        this.namespaces = new NamespacesAPI.Namespaces(this._client);
    }
}
KV.Namespaces = Namespaces;
KV.NamespacesV4PagePaginationArray = NamespacesV4PagePaginationArray;
//# sourceMappingURL=kv.mjs.map