import { APIResource } from "../../resource.js";
import * as TemporaryCredentialsAPI from "./temporary-credentials.js";
import { TemporaryCredential, TemporaryCredentialCreateParams, TemporaryCredentialCreateResponse, TemporaryCredentials } from "./temporary-credentials.js";
import * as BucketsAPI from "./buckets/buckets.js";
import { Bucket, BucketCreateParams, BucketDeleteParams, BucketDeleteResponse, BucketEditParams, BucketGetParams, BucketListParams, BucketListResponse, Buckets } from "./buckets/buckets.js";
import * as SuperSlurperAPI from "./super-slurper/super-slurper.js";
import { SuperSlurper } from "./super-slurper/super-slurper.js";
export declare class R2 extends APIResource {
    buckets: BucketsAPI.Buckets;
    temporaryCredentials: TemporaryCredentialsAPI.TemporaryCredentials;
    superSlurper: SuperSlurperAPI.SuperSlurper;
}
export declare namespace R2 {
    export { Buckets as Buckets, type Bucket as Bucket, type BucketListResponse as BucketListResponse, type BucketDeleteResponse as BucketDeleteResponse, type BucketCreateParams as BucketCreateParams, type BucketListParams as BucketListParams, type BucketDeleteParams as BucketDeleteParams, type BucketEditParams as BucketEditParams, type BucketGetParams as BucketGetParams, };
    export { TemporaryCredentials as TemporaryCredentials, type TemporaryCredential as TemporaryCredential, type TemporaryCredentialCreateResponse as TemporaryCredentialCreateResponse, type TemporaryCredentialCreateParams as TemporaryCredentialCreateParams, };
    export { SuperSlurper as SuperSlurper };
}
//# sourceMappingURL=r2.d.ts.map