import { APIResource } from "../../../resource.js";
import * as ASNAPI from "./asn.js";
import { ASN, ASNDeleteParams, ASNDeleteResponse, ASNGetParams, ASNGetResponse } from "./asn.js";
export declare class Configs extends APIResource {
    asn: ASNAPI.ASN;
}
export declare namespace Configs {
    export { ASN as ASN, type ASNDeleteResponse as ASNDeleteResponse, type ASNGetResponse as ASNGetResponse, type ASNDeleteParams as ASNDeleteParams, type ASNGetParams as ASNGetParams, };
}
//# sourceMappingURL=configs.d.ts.map