import { APIResource } from "../../resource.js";
import * as HostnamesAPI from "./hostnames/hostnames.js";
import { Hostname, HostnameCreateParams, HostnameDeleteParams, HostnameDeleteResponse, HostnameEditParams, HostnameGetParams, HostnameListParams, Hostnames, HostnamesSinglePage } from "./hostnames/hostnames.js";
export declare class Web3 extends APIResource {
    hostnames: HostnamesAPI.Hostnames;
}
export declare namespace Web3 {
    export { Hostnames as Hostnames, type Hostname as Hostname, type HostnameDeleteResponse as HostnameDeleteResponse, HostnamesSinglePage as HostnamesSinglePage, type HostnameCreateParams as HostnameCreateParams, type HostnameListParams as HostnameListParams, type HostnameDeleteParams as HostnameDeleteParams, type HostnameEditParams as HostnameEditParams, type HostnameGetParams as HostnameGetParams, };
}
//# sourceMappingURL=web3.d.ts.map