// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../../resource';
import * as TotalTLSAPI from './total-tls';
import {
  CertificateAuthority,
  TotalTLS,
  TotalTLSCreateParams,
  TotalTLSCreateResponse,
  TotalTLSGetParams,
  TotalTLSGetResponse,
} from './total-tls';

export class ACM extends APIResource {
  totalTLS: TotalTLSAPI.TotalTLS = new TotalTLSAPI.TotalTLS(this._client);
}

ACM.TotalTLS = TotalTLS;

export declare namespace ACM {
  export {
    TotalTLS as TotalTLS,
    type CertificateAuthority as CertificateAuthority,
    type TotalTLSCreateResponse as TotalTLSCreateResponse,
    type TotalTLSGetResponse as TotalTLSGetResponse,
    type TotalTLSCreateParams as TotalTLSCreateParams,
    type TotalTLSGetParams as TotalTLSGetParams,
  };
}
