// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../../resource.mjs";
import * as ConfigAPI from "./config.mjs";
import { Config, } from "./config.mjs";
export class Cmb extends APIResource {
    constructor() {
        super(...arguments);
        this.config = new ConfigAPI.Config(this._client);
    }
}
Cmb.Config = Config;
//# sourceMappingURL=cmb.mjs.map