// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
export class Attackers extends APIResource {
    /**
     * Lists attackers
     *
     * @example
     * ```ts
     * const attackers =
     *   await client.cloudforceOne.threatEvents.attackers.list({
     *     account_id: 'account_id',
     *   });
     * ```
     */
    list(params, options) {
        const { account_id } = params;
        return this._client.get(`/accounts/${account_id}/cloudforce-one/events/attackers`, options);
    }
}
//# sourceMappingURL=attackers.mjs.map