// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../../resource';
import * as HostnamesAPI from './hostnames/hostnames';
import {
  Hostname,
  HostnameCreateParams,
  HostnameDeleteParams,
  HostnameDeleteResponse,
  HostnameEditParams,
  HostnameGetParams,
  HostnameListParams,
  Hostnames,
  HostnamesSinglePage,
} from './hostnames/hostnames';

export class Web3 extends APIResource {
  hostnames: HostnamesAPI.Hostnames = new HostnamesAPI.Hostnames(this._client);
}

Web3.Hostnames = Hostnames;
Web3.HostnamesSinglePage = HostnamesSinglePage;

export declare namespace Web3 {
  export {
    Hostnames as Hostnames,
    type Hostname as Hostname,
    type HostnameDeleteResponse as HostnameDeleteResponse,
    HostnamesSinglePage as HostnamesSinglePage,
    type HostnameCreateParams as HostnameCreateParams,
    type HostnameListParams as HostnameListParams,
    type HostnameDeleteParams as HostnameDeleteParams,
    type HostnameEditParams as HostnameEditParams,
    type HostnameGetParams as HostnameGetParams,
  };
}
