import { APIResource } from "../../../resource.js";
import * as TopAPI from "./top.js";
import { Top, TopBotsParams, TopBotsResponse, TopCategoriesParams, TopCategoriesResponse } from "./top.js";
export declare class VerifiedBots extends APIResource {
    top: TopAPI.Top;
}
export declare namespace VerifiedBots {
    export { Top as Top, type TopBotsResponse as TopBotsResponse, type TopCategoriesResponse as TopCategoriesResponse, type TopBotsParams as TopBotsParams, type TopCategoriesParams as TopCategoriesParams, };
}
//# sourceMappingURL=verified-bots.d.ts.map