"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegionalHostnames = exports.RegionalHostnameListResponsesSinglePage = exports.Regions = exports.RegionListResponsesSinglePage = void 0;
var regions_1 = require("./regions.js");
Object.defineProperty(exports, "RegionListResponsesSinglePage", { enumerable: true, get: function () { return regions_1.RegionListResponsesSinglePage; } });
Object.defineProperty(exports, "Regions", { enumerable: true, get: function () { return regions_1.Regions; } });
var regional_hostnames_1 = require("./regional-hostnames.js");
Object.defineProperty(exports, "RegionalHostnameListResponsesSinglePage", { enumerable: true, get: function () { return regional_hostnames_1.RegionalHostnameListResponsesSinglePage; } });
Object.defineProperty(exports, "RegionalHostnames", { enumerable: true, get: function () { return regional_hostnames_1.RegionalHostnames; } });
//# sourceMappingURL=index.js.map