import { APIResource } from "../../../resource.js";
import * as RetentionAPI from "./retention.js";
import { Retention, RetentionCreateParams, RetentionCreateResponse, RetentionGetParams, RetentionGetResponse } from "./retention.js";
import * as CmbAPI from "./cmb/cmb.js";
import { Cmb } from "./cmb/cmb.js";
export declare class Control extends APIResource {
    retention: RetentionAPI.Retention;
    cmb: CmbAPI.Cmb;
}
export declare namespace Control {
    export { Retention as Retention, type RetentionCreateResponse as RetentionCreateResponse, type RetentionGetResponse as RetentionGetResponse, type RetentionCreateParams as RetentionCreateParams, type RetentionGetParams as RetentionGetParams, };
    export { Cmb as Cmb };
}
//# sourceMappingURL=control.d.ts.map