"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Namespaces = exports.NamespacesSinglePage = exports.Objects = exports.DurableObjectsCursorLimitPagination = void 0;
var objects_1 = require("./objects.js");
Object.defineProperty(exports, "DurableObjectsCursorLimitPagination", { enumerable: true, get: function () { return objects_1.DurableObjectsCursorLimitPagination; } });
Object.defineProperty(exports, "Objects", { enumerable: true, get: function () { return objects_1.Objects; } });
var namespaces_1 = require("./namespaces.js");
Object.defineProperty(exports, "NamespacesSinglePage", { enumerable: true, get: function () { return namespaces_1.NamespacesSinglePage; } });
Object.defineProperty(exports, "Namespaces", { enumerable: true, get: function () { return namespaces_1.Namespaces; } });
//# sourceMappingURL=index.js.map