import { APIResource } from "../../../resource.js";
import * as IQIAPI from "./iqi.js";
import { IQI, IQISummaryParams, IQISummaryResponse, IQITimeseriesGroupsParams, IQITimeseriesGroupsResponse } from "./iqi.js";
import * as SpeedAPI from "./speed/speed.js";
import { Speed, SpeedHistogramParams, SpeedHistogramResponse, SpeedSummaryParams, SpeedSummaryResponse } from "./speed/speed.js";
export declare class Quality extends APIResource {
    iqi: IQIAPI.IQI;
    speed: SpeedAPI.Speed;
}
export declare namespace Quality {
    export { IQI as IQI, type IQISummaryResponse as IQISummaryResponse, type IQITimeseriesGroupsResponse as IQITimeseriesGroupsResponse, type IQISummaryParams as IQISummaryParams, type IQITimeseriesGroupsParams as IQITimeseriesGroupsParams, };
    export { Speed as Speed, type SpeedHistogramResponse as SpeedHistogramResponse, type SpeedSummaryResponse as SpeedSummaryResponse, type SpeedHistogramParams as SpeedHistogramParams, type SpeedSummaryParams as SpeedSummaryParams, };
}
//# sourceMappingURL=quality.d.ts.map