"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.VPCFlows = exports.Rules = exports.MagicNetworkMonitoringRulesSinglePage = exports.MagicNetworkMonitoring = exports.Configs = void 0;
var index_1 = require("./configs/index.js");
Object.defineProperty(exports, "Configs", { enumerable: true, get: function () { return index_1.Configs; } });
var magic_network_monitoring_1 = require("./magic-network-monitoring.js");
Object.defineProperty(exports, "MagicNetworkMonitoring", { enumerable: true, get: function () { return magic_network_monitoring_1.MagicNetworkMonitoring; } });
var index_2 = require("./rules/index.js");
Object.defineProperty(exports, "MagicNetworkMonitoringRulesSinglePage", { enumerable: true, get: function () { return index_2.MagicNetworkMonitoringRulesSinglePage; } });
Object.defineProperty(exports, "Rules", { enumerable: true, get: function () { return index_2.Rules; } });
var index_3 = require("./vpc-flows/index.js");
Object.defineProperty(exports, "VPCFlows", { enumerable: true, get: function () { return index_3.VPCFlows; } });
//# sourceMappingURL=index.js.map