// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../../resource.mjs";
import * as CustomAPI from "./custom.mjs";
import { Custom, } from "./custom.mjs";
import * as ManagedAPI from "./managed.mjs";
import { Managed, } from "./managed.mjs";
export class Domains extends APIResource {
    constructor() {
        super(...arguments);
        this.custom = new CustomAPI.Custom(this._client);
        this.managed = new ManagedAPI.Managed(this._client);
    }
}
Domains.Custom = Custom;
Domains.Managed = Managed;
//# sourceMappingURL=domains.mjs.map