// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as V1API from "./v1/v1.mjs";
import { V1, V1ListResponsesV4PagePagination, } from "./v1/v1.mjs";
import * as V2API from "./v2/v2.mjs";
import { V2 } from "./v2/v2.mjs";
export class Images extends APIResource {
    constructor() {
        super(...arguments);
        this.v1 = new V1API.V1(this._client);
        this.v2 = new V2API.V2(this._client);
    }
}
Images.V1 = V1;
Images.V1ListResponsesV4PagePagination = V1ListResponsesV4PagePagination;
Images.V2 = V2;
//# sourceMappingURL=images.mjs.map