"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Status = exports.OutgoingResource = void 0;
var outgoing_1 = require("./outgoing.js");
Object.defineProperty(exports, "OutgoingResource", { enumerable: true, get: function () { return outgoing_1.OutgoingResource; } });
var status_1 = require("./status.js");
Object.defineProperty(exports, "Status", { enumerable: true, get: function () { return status_1.Status; } });
//# sourceMappingURL=index.js.map