"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Received = exports.Fields = void 0;
var fields_1 = require("./fields.js");
Object.defineProperty(exports, "Fields", { enumerable: true, get: function () { return fields_1.Fields; } });
var received_1 = require("./received.js");
Object.defineProperty(exports, "Received", { enumerable: true, get: function () { return received_1.Received; } });
//# sourceMappingURL=index.js.map