"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Percentiles = exports.HTTPTests = void 0;
var http_tests_1 = require("./http-tests.js");
Object.defineProperty(exports, "HTTPTests", { enumerable: true, get: function () { return http_tests_1.HTTPTests; } });
var percentiles_1 = require("./percentiles.js");
Object.defineProperty(exports, "Percentiles", { enumerable: true, get: function () { return percentiles_1.Percentiles; } });
//# sourceMappingURL=index.js.map