"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.SCIM = exports.Logs = exports.AccessRequests = void 0;
var access_requests_1 = require("./access-requests.js");
Object.defineProperty(exports, "AccessRequests", { enumerable: true, get: function () { return access_requests_1.AccessRequests; } });
var logs_1 = require("./logs.js");
Object.defineProperty(exports, "Logs", { enumerable: true, get: function () { return logs_1.Logs; } });
var index_1 = require("./scim/index.js");
Object.defineProperty(exports, "SCIM", { enumerable: true, get: function () { return index_1.SCIM; } });
//# sourceMappingURL=index.js.map