// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as InsightsAPI from "./insights/insights.mjs";
import { InsightListResponsesV4PagePagination, Insights, } from "./insights/insights.mjs";
export class SecurityCenter extends APIResource {
    constructor() {
        super(...arguments);
        this.insights = new InsightsAPI.Insights(this._client);
    }
}
SecurityCenter.Insights = Insights;
SecurityCenter.InsightListResponsesV4PagePagination = InsightListResponsesV4PagePagination;
//# sourceMappingURL=security-center.mjs.map