import { APIResource } from "../../../../resource.js";
import * as AccessRequestsAPI from "./access-requests.js";
import { AccessRequestListParams, AccessRequestListResponse, AccessRequests } from "./access-requests.js";
import * as SCIMAPI from "./scim/scim.js";
import { AccessRequest, SCIM } from "./scim/scim.js";
export declare class Logs extends APIResource {
    accessRequests: AccessRequestsAPI.AccessRequests;
    scim: SCIMAPI.SCIM;
}
export declare namespace Logs {
    export { AccessRequests as AccessRequests, type AccessRequestListResponse as AccessRequestListResponse, type AccessRequestListParams as AccessRequestListParams, };
    export { SCIM as SCIM, type AccessRequest as AccessRequest };
}
//# sourceMappingURL=logs.d.ts.map