import { APIResource } from "../../resource.js";
import * as HostnameAssociationsAPI from "./hostname-associations.js";
import { HostnameAssociation, HostnameAssociationGetParams, HostnameAssociationGetResponse, HostnameAssociationUpdateParams, HostnameAssociationUpdateResponse, HostnameAssociations, TLSHostnameAssociation } from "./hostname-associations.js";
export declare class CertificateAuthorities extends APIResource {
    hostnameAssociations: HostnameAssociationsAPI.HostnameAssociations;
}
export declare namespace CertificateAuthorities {
    export { HostnameAssociations as HostnameAssociations, type HostnameAssociation as HostnameAssociation, type TLSHostnameAssociation as TLSHostnameAssociation, type HostnameAssociationUpdateResponse as HostnameAssociationUpdateResponse, type HostnameAssociationGetResponse as HostnameAssociationGetResponse, type HostnameAssociationUpdateParams as HostnameAssociationUpdateParams, type HostnameAssociationGetParams as HostnameAssociationGetParams, };
}
//# sourceMappingURL=certificate-authorities.d.ts.map