"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.SCIM = exports.IdentityProviders = exports.IdentityProviderListResponsesSinglePage = void 0;
var identity_providers_1 = require("./identity-providers.js");
Object.defineProperty(exports, "IdentityProviderListResponsesSinglePage", { enumerable: true, get: function () { return identity_providers_1.IdentityProviderListResponsesSinglePage; } });
Object.defineProperty(exports, "IdentityProviders", { enumerable: true, get: function () { return identity_providers_1.IdentityProviders; } });
var index_1 = require("./scim/index.js");
Object.defineProperty(exports, "SCIM", { enumerable: true, get: function () { return index_1.SCIM; } });
//# sourceMappingURL=index.js.map