"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SchemaValidation = void 0;
const resource_1 = require("../../resource.js");
const SchemasAPI = __importStar(require("./schemas.js"));
const schemas_1 = require("./schemas.js");
const SettingsAPI = __importStar(require("./settings/settings.js"));
const settings_1 = require("./settings/settings.js");
class SchemaValidation extends resource_1.APIResource {
    constructor() {
        super(...arguments);
        this.schemas = new SchemasAPI.Schemas(this._client);
        this.settings = new SettingsAPI.Settings(this._client);
    }
}
exports.SchemaValidation = SchemaValidation;
SchemaValidation.Schemas = schemas_1.Schemas;
SchemaValidation.SchemaListResponsesV4PagePaginationArray = schemas_1.SchemaListResponsesV4PagePaginationArray;
SchemaValidation.Settings = settings_1.Settings;
//# sourceMappingURL=schema-validation.js.map