// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../../resource';
import * as DispatchAPI from './dispatch/dispatch';
import { Dispatch } from './dispatch/dispatch';

export class WorkersForPlatforms extends APIResource {
  dispatch: DispatchAPI.Dispatch = new DispatchAPI.Dispatch(this._client);
}

WorkersForPlatforms.Dispatch = Dispatch;

export declare namespace WorkersForPlatforms {
  export { Dispatch as Dispatch };
}
