// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { SinglePage, V4PagePaginationArray } from "../pagination.mjs";
export class MembersV4PagePaginationArray extends V4PagePaginationArray {
}
export class RolesV4PagePaginationArray extends V4PagePaginationArray {
}
export class SubscriptionsSinglePage extends SinglePage {
}
export class TokensV4PagePaginationArray extends V4PagePaginationArray {
}
export class AuditLogsV4PagePaginationArray extends V4PagePaginationArray {
}
//# sourceMappingURL=shared.mjs.map