// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
import * as SettingsAPI from "./settings.mjs";
import { Settings } from "./settings.mjs";
export class Universal extends APIResource {
    constructor() {
        super(...arguments);
        this.settings = new SettingsAPI.Settings(this._client);
    }
}
Universal.Settings = Settings;
//# sourceMappingURL=universal.mjs.map