import { APIResource } from "../../resource.js";
import * as TracesAPI from "./traces.js";
import { Trace, TraceCreateParams, TraceCreateResponse, TraceItem, Traces } from "./traces.js";
export declare class RequestTracers extends APIResource {
    traces: TracesAPI.Traces;
}
export declare namespace RequestTracers {
    export { Traces as Traces, type Trace as Trace, type TraceItem as TraceItem, type TraceCreateResponse as TraceCreateResponse, type TraceCreateParams as TraceCreateParams, };
}
//# sourceMappingURL=request-tracers.d.ts.map