// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as WidgetsAPI from "./widgets.mjs";
import { WidgetListResponsesV4PagePaginationArray, Widgets, } from "./widgets.mjs";
export class Turnstile extends APIResource {
    constructor() {
        super(...arguments);
        this.widgets = new WidgetsAPI.Widgets(this._client);
    }
}
Turnstile.Widgets = Widgets;
Turnstile.WidgetListResponsesV4PagePaginationArray = WidgetListResponsesV4PagePaginationArray;
//# sourceMappingURL=turnstile.mjs.map