import { APIResource } from "../../resource.js";
import * as SubmissionsAPI from "./submissions.js";
import { SubmissionListParams, SubmissionListResponse, SubmissionListResponsesV4PagePaginationArray, Submissions } from "./submissions.js";
import * as InvestigateAPI from "./investigate/investigate.js";
import { Investigate, InvestigateGetParams, InvestigateGetResponse, InvestigateListParams, InvestigateListResponse, InvestigateListResponsesV4PagePaginationArray } from "./investigate/investigate.js";
import * as SettingsAPI from "./settings/settings.js";
import { Settings } from "./settings/settings.js";
export declare class EmailSecurity extends APIResource {
    investigate: InvestigateAPI.Investigate;
    settings: SettingsAPI.Settings;
    submissions: SubmissionsAPI.Submissions;
}
export declare namespace EmailSecurity {
    export { Investigate as Investigate, type InvestigateListResponse as InvestigateListResponse, type InvestigateGetResponse as InvestigateGetResponse, InvestigateListResponsesV4PagePaginationArray as InvestigateListResponsesV4PagePaginationArray, type InvestigateListParams as InvestigateListParams, type InvestigateGetParams as InvestigateGetParams, };
    export { Settings as Settings };
    export { Submissions as Submissions, type SubmissionListResponse as SubmissionListResponse, SubmissionListResponsesV4PagePaginationArray as SubmissionListResponsesV4PagePaginationArray, type SubmissionListParams as SubmissionListParams, };
}
//# sourceMappingURL=email-security.d.ts.map