// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../../../../../resource';
import * as TldsAPI from './tlds/tlds';
import { TldGetParams, TldGetResponse, Tlds } from './tlds/tlds';

export class Top extends APIResource {
  tlds: TldsAPI.Tlds = new TldsAPI.Tlds(this._client);
}

Top.Tlds = Tlds;

export declare namespace Top {
  export { Tlds as Tlds, type TldGetResponse as TldGetResponse, type TldGetParams as TldGetParams };
}
