import { APIResource } from "../../resource.js";
import * as AvailableAlertsAPI from "./available-alerts.js";
import { AvailableAlertListParams, AvailableAlertListResponse, AvailableAlerts } from "./available-alerts.js";
import * as HistoryAPI from "./history.js";
import { HistoriesV4PagePaginationArray, History, HistoryListParams, HistoryResource } from "./history.js";
import * as PoliciesAPI from "./policies.js";
import { Mechanism, Policies, PoliciesSinglePage, Policy, PolicyCreateParams, PolicyCreateResponse, PolicyDeleteParams, PolicyDeleteResponse, PolicyFilter, PolicyGetParams, PolicyListParams, PolicyUpdateParams, PolicyUpdateResponse } from "./policies.js";
import * as DestinationsAPI from "./destinations/destinations.js";
import { Destinations } from "./destinations/destinations.js";
export declare class Alerting extends APIResource {
    availableAlerts: AvailableAlertsAPI.AvailableAlerts;
    destinations: DestinationsAPI.Destinations;
    history: HistoryAPI.HistoryResource;
    policies: PoliciesAPI.Policies;
}
export declare namespace Alerting {
    export { AvailableAlerts as AvailableAlerts, type AvailableAlertListResponse as AvailableAlertListResponse, type AvailableAlertListParams as AvailableAlertListParams, };
    export { Destinations as Destinations };
    export { HistoryResource as HistoryResource, type History as History, HistoriesV4PagePaginationArray as HistoriesV4PagePaginationArray, type HistoryListParams as HistoryListParams, };
    export { Policies as Policies, type Mechanism as Mechanism, type Policy as Policy, type PolicyFilter as PolicyFilter, type PolicyCreateResponse as PolicyCreateResponse, type PolicyUpdateResponse as PolicyUpdateResponse, type PolicyDeleteResponse as PolicyDeleteResponse, PoliciesSinglePage as PoliciesSinglePage, type PolicyCreateParams as PolicyCreateParams, type PolicyUpdateParams as PolicyUpdateParams, type PolicyListParams as PolicyListParams, type PolicyDeleteParams as PolicyDeleteParams, type PolicyGetParams as PolicyGetParams, };
}
//# sourceMappingURL=alerting.d.ts.map