import { APIResource } from "../../../resource.js";
import * as SettingsAPI from "./settings.js";
import { SettingEditParams, SettingGetParams, Settings, UniversalSSLSettings } from "./settings.js";
export declare class Universal extends APIResource {
    settings: SettingsAPI.Settings;
}
export declare namespace Universal {
    export { Settings as Settings, type UniversalSSLSettings as UniversalSSLSettings, type SettingEditParams as SettingEditParams, type SettingGetParams as SettingGetParams, };
}
//# sourceMappingURL=universal.d.ts.map