import { APIResource } from "../../../resource.js";
import * as TokensAPI from "./tokens.js";
import { TokenCreateParams, TokenCreateResponse, Tokens } from "./tokens.js";
export declare class VPCFlows extends APIResource {
    tokens: TokensAPI.Tokens;
}
export declare namespace VPCFlows {
    export { Tokens as Tokens, type TokenCreateResponse as TokenCreateResponse, type TokenCreateParams as TokenCreateParams, };
}
//# sourceMappingURL=vpc-flows.d.ts.map