// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
import * as FallthroughAPI from "./fallthrough.mjs";
import { Fallthrough } from "./fallthrough.mjs";
export class ExpressionTemplate extends APIResource {
    constructor() {
        super(...arguments);
        this.fallthrough = new FallthroughAPI.Fallthrough(this._client);
    }
}
ExpressionTemplate.Fallthrough = Fallthrough;
//# sourceMappingURL=expression-template.mjs.map