import type { Format } from "./types.js";
export declare const default_format: Format;
export declare const formatters: Record<Format, (str: PropertyKey) => string>;
export declare const RFC1738 = "RFC1738";
export declare const RFC3986 = "RFC3986";
//# sourceMappingURL=formats.d.ts.map