import { APIResource } from "../../../resource.js";
import * as NamespacesAPI from "./namespaces/namespaces.js";
import { NamespaceCreateParams, NamespaceCreateResponse, NamespaceDeleteParams, NamespaceDeleteResponse, NamespaceGetParams, NamespaceGetResponse, NamespaceListParams, NamespaceListResponse, NamespaceListResponsesSinglePage, Namespaces } from "./namespaces/namespaces.js";
export declare class Dispatch extends APIResource {
    namespaces: NamespacesAPI.Namespaces;
}
export declare namespace Dispatch {
    export { Namespaces as Namespaces, type NamespaceCreateResponse as NamespaceCreateResponse, type NamespaceListResponse as NamespaceListResponse, type NamespaceDeleteResponse as NamespaceDeleteResponse, type NamespaceGetResponse as NamespaceGetResponse, NamespaceListResponsesSinglePage as NamespaceListResponsesSinglePage, type NamespaceCreateParams as NamespaceCreateParams, type NamespaceListParams as NamespaceListParams, type NamespaceDeleteParams as NamespaceDeleteParams, type NamespaceGetParams as NamespaceGetParams, };
}
//# sourceMappingURL=dispatch.d.ts.map