// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
export class Profile extends APIResource {
    /**
     * Accesses your billing profile object.
     *
     * @deprecated
     */
    get(options) {
        return this._client.get('/user/billing/profile', options)._thenUnwrap((obj) => obj.result);
    }
}
//# sourceMappingURL=profile.mjs.map