import { APIResource } from "../../resource.js";
import * as Core from "../../core.js";
import { SinglePage } from "../../pagination.js";
export declare class Authors extends APIResource {
    /**
     * Author Search
     */
    list(params: AuthorListParams, options?: Core.RequestOptions): Core.PagePromise<AuthorListResponsesSinglePage, AuthorListResponse>;
}
export declare class AuthorListResponsesSinglePage extends SinglePage<AuthorListResponse> {
}
export type AuthorListResponse = unknown;
export interface AuthorListParams {
    account_id: string;
}
export declare namespace Authors {
    export { type AuthorListResponse as AuthorListResponse, AuthorListResponsesSinglePage as AuthorListResponsesSinglePage, type AuthorListParams as AuthorListParams, };
}
//# sourceMappingURL=authors.d.ts.map