// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as ProjectsAPI from "./projects/projects.mjs";
import { DeploymentsSinglePage, Projects, } from "./projects/projects.mjs";
export class Pages extends APIResource {
    constructor() {
        super(...arguments);
        this.projects = new ProjectsAPI.Projects(this._client);
    }
}
Pages.Projects = Projects;
Pages.DeploymentsSinglePage = DeploymentsSinglePage;
//# sourceMappingURL=pages.mjs.map