// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../../../resource';
import * as TopAPI from './top';
import { Top, TopBotsParams, TopBotsResponse, TopCategoriesParams, TopCategoriesResponse } from './top';

export class VerifiedBots extends APIResource {
  top: TopAPI.Top = new TopAPI.Top(this._client);
}

VerifiedBots.Top = Top;

export declare namespace VerifiedBots {
  export {
    Top as Top,
    type TopBotsResponse as TopBotsResponse,
    type TopCategoriesResponse as TopCategoriesResponse,
    type TopBotsParams as TopBotsParams,
    type TopCategoriesParams as TopCategoriesParams,
  };
}
