"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.TrustedDomains = exports.TrustedDomainListResponsesV4PagePaginationArray = exports.Settings = exports.ImpersonationRegistry = exports.ImpersonationRegistryListResponsesV4PagePaginationArray = exports.Domains = exports.DomainBulkDeleteResponsesSinglePage = exports.DomainListResponsesV4PagePaginationArray = exports.BlockSenders = exports.BlockSenderListResponsesV4PagePaginationArray = exports.AllowPolicies = exports.AllowPolicyListResponsesV4PagePaginationArray = void 0;
var allow_policies_1 = require("./allow-policies.js");
Object.defineProperty(exports, "AllowPolicyListResponsesV4PagePaginationArray", { enumerable: true, get: function () { return allow_policies_1.AllowPolicyListResponsesV4PagePaginationArray; } });
Object.defineProperty(exports, "AllowPolicies", { enumerable: true, get: function () { return allow_policies_1.AllowPolicies; } });
var block_senders_1 = require("./block-senders.js");
Object.defineProperty(exports, "BlockSenderListResponsesV4PagePaginationArray", { enumerable: true, get: function () { return block_senders_1.BlockSenderListResponsesV4PagePaginationArray; } });
Object.defineProperty(exports, "BlockSenders", { enumerable: true, get: function () { return block_senders_1.BlockSenders; } });
var domains_1 = require("./domains.js");
Object.defineProperty(exports, "DomainListResponsesV4PagePaginationArray", { enumerable: true, get: function () { return domains_1.DomainListResponsesV4PagePaginationArray; } });
Object.defineProperty(exports, "DomainBulkDeleteResponsesSinglePage", { enumerable: true, get: function () { return domains_1.DomainBulkDeleteResponsesSinglePage; } });
Object.defineProperty(exports, "Domains", { enumerable: true, get: function () { return domains_1.Domains; } });
var impersonation_registry_1 = require("./impersonation-registry.js");
Object.defineProperty(exports, "ImpersonationRegistryListResponsesV4PagePaginationArray", { enumerable: true, get: function () { return impersonation_registry_1.ImpersonationRegistryListResponsesV4PagePaginationArray; } });
Object.defineProperty(exports, "ImpersonationRegistry", { enumerable: true, get: function () { return impersonation_registry_1.ImpersonationRegistry; } });
var settings_1 = require("./settings.js");
Object.defineProperty(exports, "Settings", { enumerable: true, get: function () { return settings_1.Settings; } });
var trusted_domains_1 = require("./trusted-domains.js");
Object.defineProperty(exports, "TrustedDomainListResponsesV4PagePaginationArray", { enumerable: true, get: function () { return trusted_domains_1.TrustedDomainListResponsesV4PagePaginationArray; } });
Object.defineProperty(exports, "TrustedDomains", { enumerable: true, get: function () { return trusted_domains_1.TrustedDomains; } });
//# sourceMappingURL=index.js.map