"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Speed = exports.ScheduleResource = exports.Pages = exports.PageListResponsesSinglePage = exports.Availabilities = void 0;
var availabilities_1 = require("./availabilities.js");
Object.defineProperty(exports, "Availabilities", { enumerable: true, get: function () { return availabilities_1.Availabilities; } });
var index_1 = require("./pages/index.js");
Object.defineProperty(exports, "PageListResponsesSinglePage", { enumerable: true, get: function () { return index_1.PageListResponsesSinglePage; } });
Object.defineProperty(exports, "Pages", { enumerable: true, get: function () { return index_1.Pages; } });
var schedule_1 = require("./schedule.js");
Object.defineProperty(exports, "ScheduleResource", { enumerable: true, get: function () { return schedule_1.ScheduleResource; } });
var speed_1 = require("./speed.js");
Object.defineProperty(exports, "Speed", { enumerable: true, get: function () { return speed_1.Speed; } });
//# sourceMappingURL=index.js.map