import { APIResource } from "../../../resource.js";
import * as ACLsAPI from "./acls.js";
import { ACL, ACLCreateParams, ACLDeleteParams, ACLDeleteResponse, ACLGetParams, ACLListParams, ACLUpdateParams, ACLs, ACLsSinglePage } from "./acls.js";
import * as ForceAXFRAPI from "./force-axfr.js";
import { ForceAXFR, ForceAXFRCreateParams, ForceAXFRResource } from "./force-axfr.js";
import * as IncomingAPI from "./incoming.js";
import { Incoming, IncomingCreateParams, IncomingCreateResponse, IncomingDeleteParams, IncomingDeleteResponse, IncomingGetParams, IncomingGetResponse, IncomingResource, IncomingUpdateParams, IncomingUpdateResponse } from "./incoming.js";
import * as PeersAPI from "./peers.js";
import { Peer, PeerCreateParams, PeerDeleteParams, PeerDeleteResponse, PeerGetParams, PeerListParams, PeerUpdateParams, Peers, PeersSinglePage } from "./peers.js";
import * as TSIGsAPI from "./tsigs.js";
import { TSIG, TSIGCreateParams, TSIGDeleteParams, TSIGDeleteResponse, TSIGGetParams, TSIGListParams, TSIGUpdateParams, TSIGs, TSIGsSinglePage } from "./tsigs.js";
import * as OutgoingAPI from "./outgoing/outgoing.js";
import { DisableTransfer, EnableTransfer, Outgoing, OutgoingCreateParams, OutgoingCreateResponse, OutgoingDeleteParams, OutgoingDeleteResponse, OutgoingDisableParams, OutgoingEnableParams, OutgoingForceNotifyParams, OutgoingForceNotifyResponse, OutgoingGetParams, OutgoingGetResponse, OutgoingResource, OutgoingStatus, OutgoingUpdateParams, OutgoingUpdateResponse } from "./outgoing/outgoing.js";
export declare class ZoneTransfers extends APIResource {
    forceAXFR: ForceAXFRAPI.ForceAXFRResource;
    incoming: IncomingAPI.IncomingResource;
    outgoing: OutgoingAPI.OutgoingResource;
    acls: ACLsAPI.ACLs;
    peers: PeersAPI.Peers;
    tsigs: TSIGsAPI.TSIGs;
}
export declare namespace ZoneTransfers {
    export { ForceAXFRResource as ForceAXFRResource, type ForceAXFR as ForceAXFR, type ForceAXFRCreateParams as ForceAXFRCreateParams, };
    export { IncomingResource as IncomingResource, type Incoming as Incoming, type IncomingCreateResponse as IncomingCreateResponse, type IncomingUpdateResponse as IncomingUpdateResponse, type IncomingDeleteResponse as IncomingDeleteResponse, type IncomingGetResponse as IncomingGetResponse, type IncomingCreateParams as IncomingCreateParams, type IncomingUpdateParams as IncomingUpdateParams, type IncomingDeleteParams as IncomingDeleteParams, type IncomingGetParams as IncomingGetParams, };
    export { OutgoingResource as OutgoingResource, type DisableTransfer as DisableTransfer, type EnableTransfer as EnableTransfer, type Outgoing as Outgoing, type OutgoingStatus as OutgoingStatus, type OutgoingCreateResponse as OutgoingCreateResponse, type OutgoingUpdateResponse as OutgoingUpdateResponse, type OutgoingDeleteResponse as OutgoingDeleteResponse, type OutgoingForceNotifyResponse as OutgoingForceNotifyResponse, type OutgoingGetResponse as OutgoingGetResponse, type OutgoingCreateParams as OutgoingCreateParams, type OutgoingUpdateParams as OutgoingUpdateParams, type OutgoingDeleteParams as OutgoingDeleteParams, type OutgoingDisableParams as OutgoingDisableParams, type OutgoingEnableParams as OutgoingEnableParams, type OutgoingForceNotifyParams as OutgoingForceNotifyParams, type OutgoingGetParams as OutgoingGetParams, };
    export { ACLs as ACLs, type ACL as ACL, type ACLDeleteResponse as ACLDeleteResponse, ACLsSinglePage as ACLsSinglePage, type ACLCreateParams as ACLCreateParams, type ACLUpdateParams as ACLUpdateParams, type ACLListParams as ACLListParams, type ACLDeleteParams as ACLDeleteParams, type ACLGetParams as ACLGetParams, };
    export { Peers as Peers, type Peer as Peer, type PeerDeleteResponse as PeerDeleteResponse, PeersSinglePage as PeersSinglePage, type PeerCreateParams as PeerCreateParams, type PeerUpdateParams as PeerUpdateParams, type PeerListParams as PeerListParams, type PeerDeleteParams as PeerDeleteParams, type PeerGetParams as PeerGetParams, };
    export { TSIGs as TSIGs, type TSIG as TSIG, type TSIGDeleteResponse as TSIGDeleteResponse, TSIGsSinglePage as TSIGsSinglePage, type TSIGCreateParams as TSIGCreateParams, type TSIGUpdateParams as TSIGUpdateParams, type TSIGListParams as TSIGListParams, type TSIGDeleteParams as TSIGDeleteParams, type TSIGGetParams as TSIGGetParams, };
}
//# sourceMappingURL=zone-transfers.d.ts.map