import { APIResource } from "../../../../resource.js";
import * as SummaryAPI from "./summary.js";
import { Summary, SummaryUserAgentParams, SummaryUserAgentResponse } from "./summary.js";
export declare class Bots extends APIResource {
    summary: SummaryAPI.Summary;
}
export declare namespace Bots {
    export { Summary as Summary, type SummaryUserAgentResponse as SummaryUserAgentResponse, type SummaryUserAgentParams as SummaryUserAgentParams, };
}
//# sourceMappingURL=bots.d.ts.map