"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.IPFSUniversalPaths = exports.ContentLists = void 0;
var index_1 = require("./content-lists/index.js");
Object.defineProperty(exports, "ContentLists", { enumerable: true, get: function () { return index_1.ContentLists; } });
var ipfs_universal_paths_1 = require("./ipfs-universal-paths.js");
Object.defineProperty(exports, "IPFSUniversalPaths", { enumerable: true, get: function () { return ipfs_universal_paths_1.IPFSUniversalPaths; } });
//# sourceMappingURL=index.js.map