import { APIResource } from "../../resource.js";
import * as DispatchAPI from "./dispatch/dispatch.js";
import { Dispatch } from "./dispatch/dispatch.js";
export declare class WorkersForPlatforms extends APIResource {
    dispatch: DispatchAPI.Dispatch;
}
export declare namespace WorkersForPlatforms {
    export { Dispatch as Dispatch };
}
//# sourceMappingURL=workers-for-platforms.d.ts.map