import { APIResource } from "../../../../resource.js";
import * as GroupsAPI from "./groups.js";
import { GroupListParams, Groups } from "./groups.js";
import * as UsersAPI from "./users.js";
import { UserListParams, Users } from "./users.js";
export declare class SCIM extends APIResource {
    groups: GroupsAPI.Groups;
    users: UsersAPI.Users;
}
export declare namespace SCIM {
    export { Groups as Groups, type GroupListParams as GroupListParams };
    export { Users as Users, type UserListParams as UserListParams };
}
//# sourceMappingURL=scim.d.ts.map