"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Upload = exports.Assets = void 0;
var assets_1 = require("./assets.js");
Object.defineProperty(exports, "Assets", { enumerable: true, get: function () { return assets_1.Assets; } });
var upload_1 = require("./upload.js");
Object.defineProperty(exports, "Upload", { enumerable: true, get: function () { return upload_1.Upload; } });
//# sourceMappingURL=index.js.map