export { AddressesV4PagePaginationArray, Addresses, type Address, type AddressCreateParams, type AddressListParams, type AddressDeleteParams, type AddressGetParams, } from "./addresses.js";
export { DNSRecordsSinglePage, DNS, type DNSRecord, type DNSGetResponse, type DNSCreateParams, type DNSDeleteParams, type DNSEditParams, type DNSGetParams, } from "./dns.js";
export { EmailRouting } from "./email-routing.js";
export { EmailRoutingRulesV4PagePaginationArray, Rules, type Action, type EmailRoutingRule, type Matcher, type RuleCreateParams, type RuleUpdateParams, type RuleListParams, type RuleDeleteParams, type RuleGetParams, } from "./rules/index.js";
//# sourceMappingURL=index.d.ts.map