import { APIResource } from "../../resource.js";
import * as ProfilesAPI from "./profiles.js";
import { ProfileGetParams, ProfileGetResponse, Profiles } from "./profiles.js";
export declare class Billing extends APIResource {
    profiles: ProfilesAPI.Profiles;
}
export declare namespace Billing {
    export { Profiles as Profiles, type ProfileGetResponse as ProfileGetResponse, type ProfileGetParams as ProfileGetParams, };
}
//# sourceMappingURL=billing.d.ts.map