export { IPs, type IPGetParams } from "./ips.js";
export { Networks, type NetworkCreateParams, type NetworkDeleteParams, type NetworkEditParams, } from "./networks.js";
export { TeamnetsV4PagePaginationArray, Routes, type NetworkRoute, type Route, type Teamnet, type RouteCreateParams, type RouteListParams, type RouteDeleteParams, type RouteEditParams, type RouteGetParams, } from "./routes.js";
//# sourceMappingURL=index.d.ts.map