// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
import * as ReportsAPI from "./reports/reports.mjs";
import { Reports } from "./reports/reports.mjs";
export class Analytics extends APIResource {
    constructor() {
        super(...arguments);
        this.reports = new ReportsAPI.Reports(this._client);
    }
}
Analytics.Reports = Reports;
//# sourceMappingURL=analytics.mjs.map