"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Groups = exports.GroupListResponsesSinglePage = exports.ZeroTrustGroupsSinglePage = exports.Tags = exports.TagsSinglePage = exports.ServiceTokens = exports.ServiceTokensSinglePage = exports.Policies = exports.PolicyListResponsesSinglePage = exports.Logs = exports.Keys = exports.Infrastructure = exports.GatewayCA = exports.GatewayCAListResponsesSinglePage = exports.CustomPages = exports.CustomPageWithoutHTMLsSinglePage = exports.Certificates = exports.CertificatesSinglePage = exports.Bookmarks = exports.BookmarksSinglePage = exports.Applications = exports.ApplicationListResponsesSinglePage = exports.Users = exports.UserListResponsesSinglePage = exports.AccessUsersSinglePage = exports.Access = void 0;
var access_1 = require("./access.js");
Object.defineProperty(exports, "Access", { enumerable: true, get: function () { return access_1.Access; } });
var index_1 = require("./users/index.js");
Object.defineProperty(exports, "AccessUsersSinglePage", { enumerable: true, get: function () { return index_1.AccessUsersSinglePage; } });
Object.defineProperty(exports, "UserListResponsesSinglePage", { enumerable: true, get: function () { return index_1.UserListResponsesSinglePage; } });
Object.defineProperty(exports, "Users", { enumerable: true, get: function () { return index_1.Users; } });
var index_2 = require("./applications/index.js");
Object.defineProperty(exports, "ApplicationListResponsesSinglePage", { enumerable: true, get: function () { return index_2.ApplicationListResponsesSinglePage; } });
Object.defineProperty(exports, "Applications", { enumerable: true, get: function () { return index_2.Applications; } });
var bookmarks_1 = require("./bookmarks.js");
Object.defineProperty(exports, "BookmarksSinglePage", { enumerable: true, get: function () { return bookmarks_1.BookmarksSinglePage; } });
Object.defineProperty(exports, "Bookmarks", { enumerable: true, get: function () { return bookmarks_1.Bookmarks; } });
var index_3 = require("./certificates/index.js");
Object.defineProperty(exports, "CertificatesSinglePage", { enumerable: true, get: function () { return index_3.CertificatesSinglePage; } });
Object.defineProperty(exports, "Certificates", { enumerable: true, get: function () { return index_3.Certificates; } });
var custom_pages_1 = require("./custom-pages.js");
Object.defineProperty(exports, "CustomPageWithoutHTMLsSinglePage", { enumerable: true, get: function () { return custom_pages_1.CustomPageWithoutHTMLsSinglePage; } });
Object.defineProperty(exports, "CustomPages", { enumerable: true, get: function () { return custom_pages_1.CustomPages; } });
var gateway_ca_1 = require("./gateway-ca.js");
Object.defineProperty(exports, "GatewayCAListResponsesSinglePage", { enumerable: true, get: function () { return gateway_ca_1.GatewayCAListResponsesSinglePage; } });
Object.defineProperty(exports, "GatewayCA", { enumerable: true, get: function () { return gateway_ca_1.GatewayCA; } });
var index_4 = require("./infrastructure/index.js");
Object.defineProperty(exports, "Infrastructure", { enumerable: true, get: function () { return index_4.Infrastructure; } });
var keys_1 = require("./keys.js");
Object.defineProperty(exports, "Keys", { enumerable: true, get: function () { return keys_1.Keys; } });
var index_5 = require("./logs/index.js");
Object.defineProperty(exports, "Logs", { enumerable: true, get: function () { return index_5.Logs; } });
var policies_1 = require("./policies.js");
Object.defineProperty(exports, "PolicyListResponsesSinglePage", { enumerable: true, get: function () { return policies_1.PolicyListResponsesSinglePage; } });
Object.defineProperty(exports, "Policies", { enumerable: true, get: function () { return policies_1.Policies; } });
var service_tokens_1 = require("./service-tokens.js");
Object.defineProperty(exports, "ServiceTokensSinglePage", { enumerable: true, get: function () { return service_tokens_1.ServiceTokensSinglePage; } });
Object.defineProperty(exports, "ServiceTokens", { enumerable: true, get: function () { return service_tokens_1.ServiceTokens; } });
var tags_1 = require("./tags.js");
Object.defineProperty(exports, "TagsSinglePage", { enumerable: true, get: function () { return tags_1.TagsSinglePage; } });
Object.defineProperty(exports, "Tags", { enumerable: true, get: function () { return tags_1.Tags; } });
var groups_1 = require("./groups.js");
Object.defineProperty(exports, "ZeroTrustGroupsSinglePage", { enumerable: true, get: function () { return groups_1.ZeroTrustGroupsSinglePage; } });
Object.defineProperty(exports, "GroupListResponsesSinglePage", { enumerable: true, get: function () { return groups_1.GroupListResponsesSinglePage; } });
Object.defineProperty(exports, "Groups", { enumerable: true, get: function () { return groups_1.Groups; } });
//# sourceMappingURL=index.js.map