// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as DispatchAPI from "./dispatch/dispatch.mjs";
import { Dispatch } from "./dispatch/dispatch.mjs";
export class WorkersForPlatforms extends APIResource {
    constructor() {
        super(...arguments);
        this.dispatch = new DispatchAPI.Dispatch(this._client);
    }
}
WorkersForPlatforms.Dispatch = Dispatch;
//# sourceMappingURL=workers-for-platforms.mjs.map