// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as NamespacesAPI from "./namespaces/namespaces.mjs";
import { Namespaces, NamespacesSinglePage } from "./namespaces/namespaces.mjs";
export class DurableObjects extends APIResource {
    constructor() {
        super(...arguments);
        this.namespaces = new NamespacesAPI.Namespaces(this._client);
    }
}
DurableObjects.Namespaces = Namespaces;
DurableObjects.NamespacesSinglePage = NamespacesSinglePage;
//# sourceMappingURL=durable-objects.mjs.map