import { APIResource } from "../../../resource.js";
import * as IssueTypesAPI from "./issue-types.js";
import { IssueTypeGetParams, IssueTypeGetResponse, IssueTypeGetResponsesSinglePage, IssueTypes } from "./issue-types.js";
import * as IssuesAPI from "./issues.js";
import { IssueClassParams, IssueClassResponse, IssueDismissParams, IssueDismissResponse, IssueListParams, IssueListResponse, IssueListResponsesV4PagePagination, IssueSeverityParams, IssueSeverityResponse, IssueType, IssueTypeParams, IssueTypeResponse, Issues, SeverityQueryParam } from "./issues.js";
export declare class AttackSurfaceReport extends APIResource {
    issueTypes: IssueTypesAPI.IssueTypes;
    issues: IssuesAPI.Issues;
}
export declare namespace AttackSurfaceReport {
    export { IssueTypes as IssueTypes, type IssueTypeGetResponse as IssueTypeGetResponse, IssueTypeGetResponsesSinglePage as IssueTypeGetResponsesSinglePage, type IssueTypeGetParams as IssueTypeGetParams, };
    export { Issues as Issues, type IssueType as IssueType, type SeverityQueryParam as SeverityQueryParam, type IssueListResponse as IssueListResponse, type IssueClassResponse as IssueClassResponse, type IssueDismissResponse as IssueDismissResponse, type IssueSeverityResponse as IssueSeverityResponse, type IssueTypeResponse as IssueTypeResponse, IssueListResponsesV4PagePagination as IssueListResponsesV4PagePagination, type IssueListParams as IssueListParams, type IssueClassParams as IssueClassParams, type IssueDismissParams as IssueDismissParams, type IssueSeverityParams as IssueSeverityParams, type IssueTypeParams as IssueTypeParams, };
}
//# sourceMappingURL=attack-surface-report.d.ts.map