import { APIResource } from "../../resource.js";
import * as SFUAPI from "./sfu.js";
import { SFU, SFUCreateParams, SFUCreateResponse, SFUDeleteParams, SFUDeleteResponse, SFUGetParams, SFUGetResponse, SFUListParams, SFUListResponse, SFUListResponsesSinglePage, SFUUpdateParams, SFUUpdateResponse } from "./sfu.js";
import * as TURNAPI from "./turn.js";
import { TURN, TURNCreateParams, TURNCreateResponse, TURNDeleteParams, TURNDeleteResponse, TURNGetParams, TURNGetResponse, TURNListParams, TURNListResponse, TURNListResponsesSinglePage, TURNUpdateParams, TURNUpdateResponse } from "./turn.js";
export declare class Calls extends APIResource {
    sfu: SFUAPI.SFU;
    turn: TURNAPI.TURN;
}
export declare namespace Calls {
    export { SFU as SFU, type SFUCreateResponse as SFUCreateResponse, type SFUUpdateResponse as SFUUpdateResponse, type SFUListResponse as SFUListResponse, type SFUDeleteResponse as SFUDeleteResponse, type SFUGetResponse as SFUGetResponse, SFUListResponsesSinglePage as SFUListResponsesSinglePage, type SFUCreateParams as SFUCreateParams, type SFUUpdateParams as SFUUpdateParams, type SFUListParams as SFUListParams, type SFUDeleteParams as SFUDeleteParams, type SFUGetParams as SFUGetParams, };
    export { TURN as TURN, type TURNCreateResponse as TURNCreateResponse, type TURNUpdateResponse as TURNUpdateResponse, type TURNListResponse as TURNListResponse, type TURNDeleteResponse as TURNDeleteResponse, type TURNGetResponse as TURNGetResponse, TURNListResponsesSinglePage as TURNListResponsesSinglePage, type TURNCreateParams as TURNCreateParams, type TURNUpdateParams as TURNUpdateParams, type TURNListParams as TURNListParams, type TURNDeleteParams as TURNDeleteParams, type TURNGetParams as TURNGetParams, };
}
//# sourceMappingURL=calls.d.ts.map