import { APIResource } from "../../../resource.js";
import * as ReportsAPI from "./reports/reports.js";
import { Report, ReportGetParams, Reports } from "./reports/reports.js";
export declare class Analytics extends APIResource {
    reports: ReportsAPI.Reports;
}
export declare namespace Analytics {
    export { Reports as Reports, type Report as Report, type ReportGetParams as ReportGetParams };
}
//# sourceMappingURL=analytics.d.ts.map