// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as ProfilesAPI from "./profiles.mjs";
import { Profiles } from "./profiles.mjs";
export class Billing extends APIResource {
    constructor() {
        super(...arguments);
        this.profiles = new ProfilesAPI.Profiles(this._client);
    }
}
Billing.Profiles = Profiles;
//# sourceMappingURL=billing.mjs.map