import { APIResource } from "../../resource.js";
import * as ASNAPI from "./asn.js";
import { ASN, ASNDayReportParams, ASNDayReportResponse, ASNFullReportParams, ASNFullReportResponse } from "./asn.js";
import * as ConfigsAPI from "./configs/configs.js";
import { Configs } from "./configs/configs.js";
export declare class BotnetFeed extends APIResource {
    asn: ASNAPI.ASN;
    configs: ConfigsAPI.Configs;
}
export declare namespace BotnetFeed {
    export { ASN as ASN, type ASNDayReportResponse as ASNDayReportResponse, type ASNFullReportResponse as ASNFullReportResponse, type ASNDayReportParams as ASNDayReportParams, type ASNFullReportParams as ASNFullReportParams, };
    export { Configs as Configs };
}
//# sourceMappingURL=botnet-feed.d.ts.map