"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.TracerouteTestResults = exports.NetworkPath = void 0;
var network_path_1 = require("./network-path.js");
Object.defineProperty(exports, "NetworkPath", { enumerable: true, get: function () { return network_path_1.NetworkPath; } });
var traceroute_test_results_1 = require("./traceroute-test-results.js");
Object.defineProperty(exports, "TracerouteTestResults", { enumerable: true, get: function () { return traceroute_test_results_1.TracerouteTestResults; } });
//# sourceMappingURL=index.js.map