import { APIResource } from "../../resource.js";
import * as TraceroutesAPI from "./traceroutes.js";
import { Traceroute, TracerouteCreateParams, Traceroutes, TraceroutesSinglePage } from "./traceroutes.js";
export declare class Diagnostics extends APIResource {
    traceroutes: TraceroutesAPI.Traceroutes;
}
export declare namespace Diagnostics {
    export { Traceroutes as Traceroutes, type Traceroute as Traceroute, TraceroutesSinglePage as TraceroutesSinglePage, type TracerouteCreateParams as TracerouteCreateParams, };
}
//# sourceMappingURL=diagnostics.d.ts.map