"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Managed = exports.Domains = exports.Custom = void 0;
var custom_1 = require("./custom.js");
Object.defineProperty(exports, "Custom", { enumerable: true, get: function () { return custom_1.Custom; } });
var domains_1 = require("./domains.js");
Object.defineProperty(exports, "Domains", { enumerable: true, get: function () { return domains_1.Domains; } });
var managed_1 = require("./managed.js");
Object.defineProperty(exports, "Managed", { enumerable: true, get: function () { return managed_1.Managed; } });
//# sourceMappingURL=index.js.map