import { APIResource } from "../../resource.js";
import * as Core from "../../core.js";
import { SinglePage } from "../../pagination.js";
export declare class Tasks extends APIResource {
    /**
     * Task Search
     */
    list(params: TaskListParams, options?: Core.RequestOptions): Core.PagePromise<TaskListResponsesSinglePage, TaskListResponse>;
}
export declare class TaskListResponsesSinglePage extends SinglePage<TaskListResponse> {
}
export type TaskListResponse = unknown;
export interface TaskListParams {
    account_id: string;
}
export declare namespace Tasks {
    export { type TaskListResponse as TaskListResponse, TaskListResponsesSinglePage as TaskListResponsesSinglePage, type TaskListParams as TaskListParams, };
}
//# sourceMappingURL=tasks.d.ts.map