// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as SFUAPI from "./sfu.mjs";
import { SFU, SFUListResponsesSinglePage, } from "./sfu.mjs";
import * as TURNAPI from "./turn.mjs";
import { TURN, TURNListResponsesSinglePage, } from "./turn.mjs";
export class Calls extends APIResource {
    constructor() {
        super(...arguments);
        this.sfu = new SFUAPI.SFU(this._client);
        this.turn = new TURNAPI.TURN(this._client);
    }
}
Calls.SFU = SFU;
Calls.SFUListResponsesSinglePage = SFUListResponsesSinglePage;
Calls.TURN = TURN;
Calls.TURNListResponsesSinglePage = TURNListResponsesSinglePage;
//# sourceMappingURL=calls.mjs.map