import type { Cloudflare } from "./index.js";
export declare abstract class APIResource {
    protected _client: Cloudflare;
    constructor(client: Cloudflare);
}
//# sourceMappingURL=resource.d.ts.map