import { APIResource } from "../../../resource.js";
import * as SummaryAPI from "./summary.js";
import { Summary, SummaryBotClassParams, SummaryBotClassResponse, SummaryCompromisedParams, SummaryCompromisedResponse } from "./summary.js";
import * as TimeseriesGroupsAPI from "./timeseries-groups.js";
import { TimeseriesGroupBotClassParams, TimeseriesGroupBotClassResponse, TimeseriesGroupCompromisedParams, TimeseriesGroupCompromisedResponse, TimeseriesGroups } from "./timeseries-groups.js";
export declare class LeakedCredentials extends APIResource {
    summary: SummaryAPI.Summary;
    timeseriesGroups: TimeseriesGroupsAPI.TimeseriesGroups;
}
export declare namespace LeakedCredentials {
    export { Summary as Summary, type SummaryBotClassResponse as SummaryBotClassResponse, type SummaryCompromisedResponse as SummaryCompromisedResponse, type SummaryBotClassParams as SummaryBotClassParams, type SummaryCompromisedParams as SummaryCompromisedParams, };
    export { TimeseriesGroups as TimeseriesGroups, type TimeseriesGroupBotClassResponse as TimeseriesGroupBotClassResponse, type TimeseriesGroupCompromisedResponse as TimeseriesGroupCompromisedResponse, type TimeseriesGroupBotClassParams as TimeseriesGroupBotClassParams, type TimeseriesGroupCompromisedParams as TimeseriesGroupCompromisedParams, };
}
//# sourceMappingURL=leaked-credentials.d.ts.map