// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as RulesAPI from "./rules.mjs";
import { Rules, } from "./rules.mjs";
import * as SiteInfoAPI from "./site-info.mjs";
import { SiteInfo, SitesV4PagePaginationArray, } from "./site-info.mjs";
export class RUM extends APIResource {
    constructor() {
        super(...arguments);
        this.siteInfo = new SiteInfoAPI.SiteInfo(this._client);
        this.rules = new RulesAPI.Rules(this._client);
    }
}
RUM.SiteInfo = SiteInfo;
RUM.SitesV4PagePaginationArray = SitesV4PagePaginationArray;
RUM.Rules = Rules;
//# sourceMappingURL=rum.mjs.map