"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Updates = exports.UpdateListResponsesSinglePage = exports.SCIM = void 0;
var scim_1 = require("./scim.js");
Object.defineProperty(exports, "SCIM", { enumerable: true, get: function () { return scim_1.SCIM; } });
var updates_1 = require("./updates.js");
Object.defineProperty(exports, "UpdateListResponsesSinglePage", { enumerable: true, get: function () { return updates_1.UpdateListResponsesSinglePage; } });
Object.defineProperty(exports, "Updates", { enumerable: true, get: function () { return updates_1.Updates; } });
//# sourceMappingURL=index.js.map