import { APIResource } from "../../../resource.js";
import * as FieldsAPI from "./fields.js";
import { FieldGetParams, FieldGetResponse, Fields } from "./fields.js";
import * as JobsAPI from "./jobs.js";
import { JobGetParams, Jobs } from "./jobs.js";
export declare class Datasets extends APIResource {
    fields: FieldsAPI.Fields;
    jobs: JobsAPI.Jobs;
}
export declare namespace Datasets {
    export { Fields as Fields, type FieldGetResponse as FieldGetResponse, type FieldGetParams as FieldGetParams, };
    export { Jobs as Jobs, type JobGetParams as JobGetParams };
}
//# sourceMappingURL=datasets.d.ts.map