// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as RulesAPI from "./rules.mjs";
import { RuleListResponsesSinglePage, RuleUpdateResponsesSinglePage, Rules, } from "./rules.mjs";
export class CloudConnector extends APIResource {
    constructor() {
        super(...arguments);
        this.rules = new RulesAPI.Rules(this._client);
    }
}
CloudConnector.Rules = Rules;
CloudConnector.RuleUpdateResponsesSinglePage = RuleUpdateResponsesSinglePage;
CloudConnector.RuleListResponsesSinglePage = RuleListResponsesSinglePage;
//# sourceMappingURL=cloud-connector.mjs.map