// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as TracesAPI from "./traces.mjs";
import { Traces } from "./traces.mjs";
export class RequestTracers extends APIResource {
    constructor() {
        super(...arguments);
        this.traces = new TracesAPI.Traces(this._client);
    }
}
RequestTracers.Traces = Traces;
//# sourceMappingURL=request-tracers.mjs.map