"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Users = exports.SCIM = exports.Groups = void 0;
var groups_1 = require("./groups.js");
Object.defineProperty(exports, "Groups", { enumerable: true, get: function () { return groups_1.Groups; } });
var scim_1 = require("./scim.js");
Object.defineProperty(exports, "SCIM", { enumerable: true, get: function () { return scim_1.SCIM; } });
var users_1 = require("./users.js");
Object.defineProperty(exports, "Users", { enumerable: true, get: function () { return users_1.Users; } });
//# sourceMappingURL=index.js.map