"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserGroups = exports.UserGroupListResponsesV4PagePaginationArray = exports.ResourceGroups = exports.ResourceGroupListResponsesV4PagePaginationArray = exports.PermissionGroups = exports.PermissionGroupListResponsesV4PagePaginationArray = exports.IAM = void 0;
var iam_1 = require("./iam.js");
Object.defineProperty(exports, "IAM", { enumerable: true, get: function () { return iam_1.IAM; } });
var permission_groups_1 = require("./permission-groups.js");
Object.defineProperty(exports, "PermissionGroupListResponsesV4PagePaginationArray", { enumerable: true, get: function () { return permission_groups_1.PermissionGroupListResponsesV4PagePaginationArray; } });
Object.defineProperty(exports, "PermissionGroups", { enumerable: true, get: function () { return permission_groups_1.PermissionGroups; } });
var resource_groups_1 = require("./resource-groups.js");
Object.defineProperty(exports, "ResourceGroupListResponsesV4PagePaginationArray", { enumerable: true, get: function () { return resource_groups_1.ResourceGroupListResponsesV4PagePaginationArray; } });
Object.defineProperty(exports, "ResourceGroups", { enumerable: true, get: function () { return resource_groups_1.ResourceGroups; } });
var index_1 = require("./user-groups/index.js");
Object.defineProperty(exports, "UserGroupListResponsesV4PagePaginationArray", { enumerable: true, get: function () { return index_1.UserGroupListResponsesV4PagePaginationArray; } });
Object.defineProperty(exports, "UserGroups", { enumerable: true, get: function () { return index_1.UserGroups; } });
//# sourceMappingURL=index.js.map