"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Resources = exports.ResourceListResponsesV4PagePaginationArray = exports.OnRamps = exports.OnRampListResponsesSinglePage = exports.MagicCloudNetworking = exports.CloudIntegrations = exports.CloudIntegrationListResponsesSinglePage = exports.CatalogSyncs = exports.CatalogSyncListResponsesSinglePage = void 0;
var index_1 = require("./catalog-syncs/index.js");
Object.defineProperty(exports, "CatalogSyncListResponsesSinglePage", { enumerable: true, get: function () { return index_1.CatalogSyncListResponsesSinglePage; } });
Object.defineProperty(exports, "CatalogSyncs", { enumerable: true, get: function () { return index_1.CatalogSyncs; } });
var cloud_integrations_1 = require("./cloud-integrations.js");
Object.defineProperty(exports, "CloudIntegrationListResponsesSinglePage", { enumerable: true, get: function () { return cloud_integrations_1.CloudIntegrationListResponsesSinglePage; } });
Object.defineProperty(exports, "CloudIntegrations", { enumerable: true, get: function () { return cloud_integrations_1.CloudIntegrations; } });
var magic_cloud_networking_1 = require("./magic-cloud-networking.js");
Object.defineProperty(exports, "MagicCloudNetworking", { enumerable: true, get: function () { return magic_cloud_networking_1.MagicCloudNetworking; } });
var index_2 = require("./on-ramps/index.js");
Object.defineProperty(exports, "OnRampListResponsesSinglePage", { enumerable: true, get: function () { return index_2.OnRampListResponsesSinglePage; } });
Object.defineProperty(exports, "OnRamps", { enumerable: true, get: function () { return index_2.OnRamps; } });
var resources_1 = require("./resources.js");
Object.defineProperty(exports, "ResourceListResponsesV4PagePaginationArray", { enumerable: true, get: function () { return resources_1.ResourceListResponsesV4PagePaginationArray; } });
Object.defineProperty(exports, "Resources", { enumerable: true, get: function () { return resources_1.Resources; } });
//# sourceMappingURL=index.js.map