import { APIResource } from "../../../resource.js";
import * as AllowPoliciesAPI from "./allow-policies.js";
import { AllowPolicies, AllowPolicyCreateParams, AllowPolicyCreateResponse, AllowPolicyDeleteParams, AllowPolicyDeleteResponse, AllowPolicyEditParams, AllowPolicyEditResponse, AllowPolicyGetParams, AllowPolicyGetResponse, AllowPolicyListParams, AllowPolicyListResponse, AllowPolicyListResponsesV4PagePaginationArray } from "./allow-policies.js";
import * as BlockSendersAPI from "./block-senders.js";
import { BlockSenderCreateParams, BlockSenderCreateResponse, BlockSenderDeleteParams, BlockSenderDeleteResponse, BlockSenderEditParams, BlockSenderEditResponse, BlockSenderGetParams, BlockSenderGetResponse, BlockSenderListParams, BlockSenderListResponse, BlockSenderListResponsesV4PagePaginationArray, BlockSenders } from "./block-senders.js";
import * as DomainsAPI from "./domains.js";
import { DomainBulkDeleteParams, DomainBulkDeleteResponse, DomainBulkDeleteResponsesSinglePage, DomainDeleteParams, DomainDeleteResponse, DomainEditParams, DomainEditResponse, DomainGetParams, DomainGetResponse, DomainListParams, DomainListResponse, DomainListResponsesV4PagePaginationArray, Domains } from "./domains.js";
import * as ImpersonationRegistryAPI from "./impersonation-registry.js";
import { ImpersonationRegistry, ImpersonationRegistryCreateParams, ImpersonationRegistryCreateResponse, ImpersonationRegistryDeleteParams, ImpersonationRegistryDeleteResponse, ImpersonationRegistryEditParams, ImpersonationRegistryEditResponse, ImpersonationRegistryGetParams, ImpersonationRegistryGetResponse, ImpersonationRegistryListParams, ImpersonationRegistryListResponse, ImpersonationRegistryListResponsesV4PagePaginationArray } from "./impersonation-registry.js";
import * as TrustedDomainsAPI from "./trusted-domains.js";
import { TrustedDomainCreateParams, TrustedDomainCreateResponse, TrustedDomainDeleteParams, TrustedDomainDeleteResponse, TrustedDomainEditParams, TrustedDomainEditResponse, TrustedDomainGetParams, TrustedDomainGetResponse, TrustedDomainListParams, TrustedDomainListResponse, TrustedDomainListResponsesV4PagePaginationArray, TrustedDomains } from "./trusted-domains.js";
export declare class Settings extends APIResource {
    allowPolicies: AllowPoliciesAPI.AllowPolicies;
    blockSenders: BlockSendersAPI.BlockSenders;
    domains: DomainsAPI.Domains;
    impersonationRegistry: ImpersonationRegistryAPI.ImpersonationRegistry;
    trustedDomains: TrustedDomainsAPI.TrustedDomains;
}
export declare namespace Settings {
    export { AllowPolicies as AllowPolicies, type AllowPolicyCreateResponse as AllowPolicyCreateResponse, type AllowPolicyListResponse as AllowPolicyListResponse, type AllowPolicyDeleteResponse as AllowPolicyDeleteResponse, type AllowPolicyEditResponse as AllowPolicyEditResponse, type AllowPolicyGetResponse as AllowPolicyGetResponse, AllowPolicyListResponsesV4PagePaginationArray as AllowPolicyListResponsesV4PagePaginationArray, type AllowPolicyCreateParams as AllowPolicyCreateParams, type AllowPolicyListParams as AllowPolicyListParams, type AllowPolicyDeleteParams as AllowPolicyDeleteParams, type AllowPolicyEditParams as AllowPolicyEditParams, type AllowPolicyGetParams as AllowPolicyGetParams, };
    export { BlockSenders as BlockSenders, type BlockSenderCreateResponse as BlockSenderCreateResponse, type BlockSenderListResponse as BlockSenderListResponse, type BlockSenderDeleteResponse as BlockSenderDeleteResponse, type BlockSenderEditResponse as BlockSenderEditResponse, type BlockSenderGetResponse as BlockSenderGetResponse, BlockSenderListResponsesV4PagePaginationArray as BlockSenderListResponsesV4PagePaginationArray, type BlockSenderCreateParams as BlockSenderCreateParams, type BlockSenderListParams as BlockSenderListParams, type BlockSenderDeleteParams as BlockSenderDeleteParams, type BlockSenderEditParams as BlockSenderEditParams, type BlockSenderGetParams as BlockSenderGetParams, };
    export { Domains as Domains, type DomainListResponse as DomainListResponse, type DomainDeleteResponse as DomainDeleteResponse, type DomainBulkDeleteResponse as DomainBulkDeleteResponse, type DomainEditResponse as DomainEditResponse, type DomainGetResponse as DomainGetResponse, DomainListResponsesV4PagePaginationArray as DomainListResponsesV4PagePaginationArray, DomainBulkDeleteResponsesSinglePage as DomainBulkDeleteResponsesSinglePage, type DomainListParams as DomainListParams, type DomainDeleteParams as DomainDeleteParams, type DomainBulkDeleteParams as DomainBulkDeleteParams, type DomainEditParams as DomainEditParams, type DomainGetParams as DomainGetParams, };
    export { ImpersonationRegistry as ImpersonationRegistry, type ImpersonationRegistryCreateResponse as ImpersonationRegistryCreateResponse, type ImpersonationRegistryListResponse as ImpersonationRegistryListResponse, type ImpersonationRegistryDeleteResponse as ImpersonationRegistryDeleteResponse, type ImpersonationRegistryEditResponse as ImpersonationRegistryEditResponse, type ImpersonationRegistryGetResponse as ImpersonationRegistryGetResponse, ImpersonationRegistryListResponsesV4PagePaginationArray as ImpersonationRegistryListResponsesV4PagePaginationArray, type ImpersonationRegistryCreateParams as ImpersonationRegistryCreateParams, type ImpersonationRegistryListParams as ImpersonationRegistryListParams, type ImpersonationRegistryDeleteParams as ImpersonationRegistryDeleteParams, type ImpersonationRegistryEditParams as ImpersonationRegistryEditParams, type ImpersonationRegistryGetParams as ImpersonationRegistryGetParams, };
    export { TrustedDomains as TrustedDomains, type TrustedDomainCreateResponse as TrustedDomainCreateResponse, type TrustedDomainListResponse as TrustedDomainListResponse, type TrustedDomainDeleteResponse as TrustedDomainDeleteResponse, type TrustedDomainEditResponse as TrustedDomainEditResponse, type TrustedDomainGetResponse as TrustedDomainGetResponse, TrustedDomainListResponsesV4PagePaginationArray as TrustedDomainListResponsesV4PagePaginationArray, type TrustedDomainCreateParams as TrustedDomainCreateParams, type TrustedDomainListParams as TrustedDomainListParams, type TrustedDomainDeleteParams as TrustedDomainDeleteParams, type TrustedDomainEditParams as TrustedDomainEditParams, type TrustedDomainGetParams as TrustedDomainGetParams, };
}
//# sourceMappingURL=settings.d.ts.map