"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Universal = exports.Settings = void 0;
var settings_1 = require("./settings.js");
Object.defineProperty(exports, "Settings", { enumerable: true, get: function () { return settings_1.Settings; } });
var universal_1 = require("./universal.js");
Object.defineProperty(exports, "Universal", { enumerable: true, get: function () { return universal_1.Universal; } });
//# sourceMappingURL=index.js.map