import { APIResource } from "../../../../resource.js";
import * as Core from "../../../../core.js";
import * as OutgoingAPI from "./outgoing.js";
export declare class Status extends APIResource {
    /**
     * Get primary zone transfer status.
     *
     * @example
     * ```ts
     * const enableTransfer =
     *   await client.dns.zoneTransfers.outgoing.status.get({
     *     zone_id: '269d8f4853475ca241c4e730be286b20',
     *   });
     * ```
     */
    get(params: StatusGetParams, options?: Core.RequestOptions): Core.APIPromise<OutgoingAPI.EnableTransfer>;
}
export interface StatusGetParams {
    zone_id: string;
}
export declare namespace Status {
    export { type StatusGetParams as StatusGetParams };
}
//# sourceMappingURL=status.d.ts.map