"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Registrar = exports.Domains = exports.DomainsSinglePage = void 0;
var domains_1 = require("./domains.js");
Object.defineProperty(exports, "DomainsSinglePage", { enumerable: true, get: function () { return domains_1.DomainsSinglePage; } });
Object.defineProperty(exports, "Domains", { enumerable: true, get: function () { return domains_1.Domains; } });
var registrar_1 = require("./registrar.js");
Object.defineProperty(exports, "Registrar", { enumerable: true, get: function () { return registrar_1.Registrar; } });
//# sourceMappingURL=index.js.map