// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as TraceroutesAPI from "./traceroutes.mjs";
import { Traceroutes, TraceroutesSinglePage } from "./traceroutes.mjs";
export class Diagnostics extends APIResource {
    constructor() {
        super(...arguments);
        this.traceroutes = new TraceroutesAPI.Traceroutes(this._client);
    }
}
Diagnostics.Traceroutes = Traceroutes;
Diagnostics.TraceroutesSinglePage = TraceroutesSinglePage;
//# sourceMappingURL=diagnostics.mjs.map