"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Full = exports.Configs = void 0;
var configs_1 = require("./configs.js");
Object.defineProperty(exports, "Configs", { enumerable: true, get: function () { return configs_1.Configs; } });
var full_1 = require("./full.js");
Object.defineProperty(exports, "Full", { enumerable: true, get: function () { return full_1.Full; } });
//# sourceMappingURL=index.js.map