"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.PCAPs = exports.PCAPListResponsesSinglePage = exports.OwnershipResource = exports.OwnershipsSinglePage = exports.Download = void 0;
var download_1 = require("./download.js");
Object.defineProperty(exports, "Download", { enumerable: true, get: function () { return download_1.Download; } });
var ownership_1 = require("./ownership.js");
Object.defineProperty(exports, "OwnershipsSinglePage", { enumerable: true, get: function () { return ownership_1.OwnershipsSinglePage; } });
Object.defineProperty(exports, "OwnershipResource", { enumerable: true, get: function () { return ownership_1.OwnershipResource; } });
var pcaps_1 = require("./pcaps.js");
Object.defineProperty(exports, "PCAPListResponsesSinglePage", { enumerable: true, get: function () { return pcaps_1.PCAPListResponsesSinglePage; } });
Object.defineProperty(exports, "PCAPs", { enumerable: true, get: function () { return pcaps_1.PCAPs; } });
//# sourceMappingURL=index.js.map