import { APIResource } from "../../resource.js";
import * as ListsAPI from "./lists/lists.js";
import { Hostname, ListCreateParams, ListCreateResponse, ListDeleteParams, ListDeleteResponse, ListGetParams, ListGetResponse, ListListParams, ListUpdateParams, ListUpdateResponse, Lists, ListsList, ListsListsSinglePage, Redirect } from "./lists/lists.js";
export declare class Rules extends APIResource {
    lists: ListsAPI.Lists;
}
export declare namespace Rules {
    export { Lists as Lists, type Hostname as Hostname, type ListsList as ListsList, type Redirect as Redirect, type ListCreateResponse as ListCreateResponse, type ListUpdateResponse as ListUpdateResponse, type ListDeleteResponse as ListDeleteResponse, type ListGetResponse as ListGetResponse, ListsListsSinglePage as ListsListsSinglePage, type ListCreateParams as ListCreateParams, type ListUpdateParams as ListUpdateParams, type ListListParams as ListListParams, type ListDeleteParams as ListDeleteParams, type ListGetParams as ListGetParams, };
}
//# sourceMappingURL=rules.d.ts.map