import { APIResource } from "../../../resource.js";
import * as TopAPI from "./top/top.js";
import { Top, TopDomainCategoriesParams, TopDomainCategoriesResponse } from "./top/top.js";
export declare class RobotsTXT extends APIResource {
    top: TopAPI.Top;
}
export declare namespace RobotsTXT {
    export { Top as Top, type TopDomainCategoriesResponse as TopDomainCategoriesResponse, type TopDomainCategoriesParams as TopDomainCategoriesParams, };
}
//# sourceMappingURL=robots-txt.d.ts.map