import { APIResource } from "../../../resource.js";
import * as TelemetryAPI from "./telemetry.js";
import { Telemetry, TelemetryKeysParams, TelemetryKeysResponse, TelemetryKeysResponsesSinglePage, TelemetryQueryParams, TelemetryQueryResponse, TelemetryValuesParams, TelemetryValuesResponse, TelemetryValuesResponsesSinglePage } from "./telemetry.js";
export declare class Observability extends APIResource {
    telemetry: TelemetryAPI.Telemetry;
}
export declare namespace Observability {
    export { Telemetry as Telemetry, type TelemetryKeysResponse as TelemetryKeysResponse, type TelemetryQueryResponse as TelemetryQueryResponse, type TelemetryValuesResponse as TelemetryValuesResponse, TelemetryKeysResponsesSinglePage as TelemetryKeysResponsesSinglePage, TelemetryValuesResponsesSinglePage as TelemetryValuesResponsesSinglePage, type TelemetryKeysParams as TelemetryKeysParams, type TelemetryQueryParams as TelemetryQueryParams, type TelemetryValuesParams as TelemetryValuesParams, };
}
//# sourceMappingURL=observability.d.ts.map