// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../resource.mjs";
import * as ColosAPI from "./colos.mjs";
import { ColoListResponsesSinglePage, Colos } from "./colos.mjs";
import * as TracerouteTestsAPI from "./traceroute-tests.mjs";
import { TracerouteTests, } from "./traceroute-tests.mjs";
import * as WARPChangeEventsAPI from "./warp-change-events.mjs";
import { WARPChangeEvents } from "./warp-change-events.mjs";
import * as CommandsAPI from "./commands/commands.mjs";
import { CommandListResponsesV4PagePagination, Commands, } from "./commands/commands.mjs";
import * as FleetStatusAPI from "./fleet-status/fleet-status.mjs";
import { FleetStatus, } from "./fleet-status/fleet-status.mjs";
import * as HTTPTestsAPI from "./http-tests/http-tests.mjs";
import { HTTPTests } from "./http-tests/http-tests.mjs";
import * as TestsAPI from "./tests/tests.mjs";
import { TestsV4PagePagination } from "./tests/tests.mjs";
import * as TracerouteTestResultsAPI from "./traceroute-test-results/traceroute-test-results.mjs";
import { TracerouteTestResults } from "./traceroute-test-results/traceroute-test-results.mjs";
export class DEX extends APIResource {
    constructor() {
        super(...arguments);
        this.warpChangeEvents = new WARPChangeEventsAPI.WARPChangeEvents(this._client);
        this.commands = new CommandsAPI.Commands(this._client);
        this.colos = new ColosAPI.Colos(this._client);
        this.fleetStatus = new FleetStatusAPI.FleetStatus(this._client);
        this.httpTests = new HTTPTestsAPI.HTTPTests(this._client);
        this.tests = new TestsAPI.Tests(this._client);
        this.tracerouteTestResults = new TracerouteTestResultsAPI.TracerouteTestResults(this._client);
        this.tracerouteTests = new TracerouteTestsAPI.TracerouteTests(this._client);
    }
}
DEX.WARPChangeEvents = WARPChangeEvents;
DEX.Commands = Commands;
DEX.CommandListResponsesV4PagePagination = CommandListResponsesV4PagePagination;
DEX.Colos = Colos;
DEX.ColoListResponsesSinglePage = ColoListResponsesSinglePage;
DEX.FleetStatus = FleetStatus;
DEX.HTTPTests = HTTPTests;
DEX.TestsV4PagePagination = TestsV4PagePagination;
DEX.TracerouteTestResults = TracerouteTestResults;
DEX.TracerouteTests = TracerouteTests;
//# sourceMappingURL=dex.mjs.map