import { APIResource } from "../../resource.js";
import * as InsightsAPI from "./insights/insights.js";
import { InsightDismissParams, InsightDismissResponse, InsightListParams, InsightListResponse, InsightListResponsesV4PagePagination, Insights } from "./insights/insights.js";
export declare class SecurityCenter extends APIResource {
    insights: InsightsAPI.Insights;
}
export declare namespace SecurityCenter {
    export { Insights as Insights, type InsightListResponse as InsightListResponse, type InsightDismissResponse as InsightDismissResponse, InsightListResponsesV4PagePagination as InsightListResponsesV4PagePagination, type InsightListParams as InsightListParams, type InsightDismissParams as InsightDismissParams, };
}
//# sourceMappingURL=security-center.d.ts.map