export { Advertisements, type Advertisement, type AdvertisementEditParams } from "./advertisements.js";
export { MagicNetworkMonitoringRulesSinglePage, Rules, type MagicNetworkMonitoringRule, type RuleCreateParams, type RuleUpdateParams, type RuleListParams, type RuleDeleteParams, type RuleEditParams, type RuleGetParams, } from "./rules.js";
//# sourceMappingURL=index.d.ts.map