import { APIResource } from "../../resource.js";
import * as RayIDAPI from "./rayid.js";
import { RayID, RayIDGetParams, RayIDGetResponse } from "./rayid.js";
import * as ControlAPI from "./control/control.js";
import { Control } from "./control/control.js";
import * as ReceivedAPI from "./received/received.js";
import { Received, ReceivedGetParams, ReceivedGetResponse } from "./received/received.js";
export declare class Logs extends APIResource {
    control: ControlAPI.Control;
    RayID: RayIDAPI.RayID;
    received: ReceivedAPI.Received;
}
export declare namespace Logs {
    export { Control as Control };
    export { RayID as RayID, type RayIDGetResponse as RayIDGetResponse, type RayIDGetParams as RayIDGetParams };
    export { Received as Received, type ReceivedGetResponse as ReceivedGetResponse, type ReceivedGetParams as ReceivedGetParams, };
}
//# sourceMappingURL=logs.d.ts.map