export { Malicious, type MaliciousGetResponse, type MaliciousGetParams } from "./malicious.js";
export { Spam, type SpamGetResponse, type SpamGetParams } from "./spam.js";
export { Spoof, type SpoofGetResponse, type SpoofGetParams } from "./spoof.js";
export { Tlds, type TldGetResponse, type TldGetParams } from "./tlds.js";
//# sourceMappingURL=index.d.ts.map