// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../../../../resource.mjs";
import * as UpdatesAPI from "./updates.mjs";
import { UpdateListResponsesSinglePage, Updates } from "./updates.mjs";
export class SCIM extends APIResource {
    constructor() {
        super(...arguments);
        this.updates = new UpdatesAPI.Updates(this._client);
    }
}
SCIM.Updates = Updates;
SCIM.UpdateListResponsesSinglePage = UpdateListResponsesSinglePage;
//# sourceMappingURL=scim.mjs.map