// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../../../resource';
import * as SettingsAPI from './settings';
import { SettingEditParams, SettingGetParams, Settings, UniversalSSLSettings } from './settings';

export class Universal extends APIResource {
  settings: SettingsAPI.Settings = new SettingsAPI.Settings(this._client);
}

Universal.Settings = Settings;

export declare namespace Universal {
  export {
    Settings as Settings,
    type UniversalSSLSettings as UniversalSSLSettings,
    type SettingEditParams as SettingEditParams,
    type SettingGetParams as SettingGetParams,
  };
}
