import { APIResource } from "../../resource.js";
import * as NamespacesAPI from "./namespaces/namespaces.js";
import { Namespace, NamespaceListParams, Namespaces, NamespacesSinglePage } from "./namespaces/namespaces.js";
export declare class DurableObjects extends APIResource {
    namespaces: NamespacesAPI.Namespaces;
}
export declare namespace DurableObjects {
    export { Namespaces as Namespaces, type Namespace as Namespace, NamespacesSinglePage as NamespacesSinglePage, type NamespaceListParams as NamespaceListParams, };
}
//# sourceMappingURL=durable-objects.d.ts.map