export { RegionListResponsesSinglePage, Regions, type RegionListResponse, type RegionListParams, } from "./regions.js";
export { RegionalHostnameListResponsesSinglePage, RegionalHostnames, type RegionalHostnameCreateResponse, type RegionalHostnameListResponse, type RegionalHostnameDeleteResponse, type RegionalHostnameEditResponse, type RegionalHostnameGetResponse, type RegionalHostnameCreateParams, type RegionalHostnameListParams, type RegionalHostnameDeleteParams, type RegionalHostnameEditParams, type RegionalHostnameGetParams, } from "./regional-hostnames.js";
//# sourceMappingURL=index.d.ts.map