// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as DomainsAPI from "./domains.mjs";
import { Domains, DomainsSinglePage, } from "./domains.mjs";
export class Registrar extends APIResource {
    constructor() {
        super(...arguments);
        this.domains = new DomainsAPI.Domains(this._client);
    }
}
Registrar.Domains = Domains;
Registrar.DomainsSinglePage = DomainsSinglePage;
//# sourceMappingURL=registrar.mjs.map