export { ACLsSinglePage, ACLs, type ACL, type ACLConfiguration, type AllowedProtocol, type Subnet, type ACLCreateParams, type ACLUpdateParams, type ACLListParams, type ACLDeleteParams, type ACLEditParams, type ACLGetParams, } from "./acls.js";
export { LANsSinglePage, LANs, type DHCPRelay, type DHCPServer, type LAN, type LANStaticAddressing, type Nat, type RoutedSubnet, type LANCreateParams, type LANUpdateParams, type LANListParams, type LANDeleteParams, type LANEditParams, type LANGetParams, } from "./lans.js";
export { SitesSinglePage, Sites, type Site, type SiteLocation, type SiteCreateParams, type SiteUpdateParams, type SiteListParams, type SiteDeleteParams, type SiteEditParams, type SiteGetParams, } from "./sites.js";
export { WANsSinglePage, WANs, type WAN, type WANStaticAddressing, type WANCreateParams, type WANUpdateParams, type WANListParams, type WANDeleteParams, type WANEditParams, type WANGetParams, } from "./wans.js";
//# sourceMappingURL=index.d.ts.map