"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Zones = exports.IPs = exports.AddressMaps = exports.AddressMapsSinglePage = exports.Accounts = void 0;
var accounts_1 = require("./accounts.js");
Object.defineProperty(exports, "Accounts", { enumerable: true, get: function () { return accounts_1.Accounts; } });
var address_maps_1 = require("./address-maps.js");
Object.defineProperty(exports, "AddressMapsSinglePage", { enumerable: true, get: function () { return address_maps_1.AddressMapsSinglePage; } });
Object.defineProperty(exports, "AddressMaps", { enumerable: true, get: function () { return address_maps_1.AddressMaps; } });
var ips_1 = require("./ips.js");
Object.defineProperty(exports, "IPs", { enumerable: true, get: function () { return ips_1.IPs; } });
var zones_1 = require("./zones.js");
Object.defineProperty(exports, "Zones", { enumerable: true, get: function () { return zones_1.Zones; } });
//# sourceMappingURL=index.js.map