import { APIResource } from "../../../resource.js";
import * as AggregatesAPI from "./aggregates/aggregates.js";
import { Aggregates } from "./aggregates/aggregates.js";
import * as EventsAPI from "./events/events.js";
import { Dimension, Events } from "./events/events.js";
export declare class Analytics extends APIResource {
    aggregates: AggregatesAPI.Aggregates;
    events: EventsAPI.Events;
}
export declare namespace Analytics {
    export { Aggregates as Aggregates };
    export { Events as Events, type Dimension as Dimension };
}
//# sourceMappingURL=analytics.d.ts.map