// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../../../resource';
import * as CertificatesAPI from './certificates';
import {
  CertificateDeleteParams,
  CertificateDeleteResponse,
  CertificateUpdateParams,
  CertificateUpdateResponse,
  Certificates,
} from './certificates';

export class CertificatePack extends APIResource {
  certificates: CertificatesAPI.Certificates = new CertificatesAPI.Certificates(this._client);
}

CertificatePack.Certificates = Certificates;

export declare namespace CertificatePack {
  export {
    Certificates as Certificates,
    type CertificateUpdateResponse as CertificateUpdateResponse,
    type CertificateDeleteResponse as CertificateDeleteResponse,
    type CertificateUpdateParams as CertificateUpdateParams,
    type CertificateDeleteParams as CertificateDeleteParams,
  };
}
