"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuditLogsV4PagePaginationArray = exports.TokensV4PagePaginationArray = exports.SubscriptionsSinglePage = exports.RolesV4PagePaginationArray = exports.MembersV4PagePaginationArray = void 0;
const pagination_1 = require("../pagination.js");
class MembersV4PagePaginationArray extends pagination_1.V4PagePaginationArray {
}
exports.MembersV4PagePaginationArray = MembersV4PagePaginationArray;
class RolesV4PagePaginationArray extends pagination_1.V4PagePaginationArray {
}
exports.RolesV4PagePaginationArray = RolesV4PagePaginationArray;
class SubscriptionsSinglePage extends pagination_1.SinglePage {
}
exports.SubscriptionsSinglePage = SubscriptionsSinglePage;
class TokensV4PagePaginationArray extends pagination_1.V4PagePaginationArray {
}
exports.TokensV4PagePaginationArray = TokensV4PagePaginationArray;
class AuditLogsV4PagePaginationArray extends pagination_1.V4PagePaginationArray {
}
exports.AuditLogsV4PagePaginationArray = AuditLogsV4PagePaginationArray;
//# sourceMappingURL=shared.js.map