"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.OnRamps = exports.OnRampListResponsesSinglePage = exports.AddressSpaces = void 0;
var address_spaces_1 = require("./address-spaces.js");
Object.defineProperty(exports, "AddressSpaces", { enumerable: true, get: function () { return address_spaces_1.AddressSpaces; } });
var on_ramps_1 = require("./on-ramps.js");
Object.defineProperty(exports, "OnRampListResponsesSinglePage", { enumerable: true, get: function () { return on_ramps_1.OnRampListResponsesSinglePage; } });
Object.defineProperty(exports, "OnRamps", { enumerable: true, get: function () { return on_ramps_1.OnRamps; } });
//# sourceMappingURL=index.js.map