// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as QuotaAPI from "./quota.mjs";
import { Quota } from "./quota.mjs";
import * as StoresAPI from "./stores/stores.mjs";
import { StoreCreateResponsesSinglePage, StoreListResponsesV4PagePaginationArray, Stores, } from "./stores/stores.mjs";
export class SecretsStore extends APIResource {
    constructor() {
        super(...arguments);
        this.stores = new StoresAPI.Stores(this._client);
        this.quota = new QuotaAPI.Quota(this._client);
    }
}
SecretsStore.Stores = Stores;
SecretsStore.StoreCreateResponsesSinglePage = StoreCreateResponsesSinglePage;
SecretsStore.StoreListResponsesV4PagePaginationArray = StoreListResponsesV4PagePaginationArray;
SecretsStore.Quota = Quota;
//# sourceMappingURL=secrets-store.mjs.map