"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.V2 = exports.DirectUploads = void 0;
var direct_uploads_1 = require("./direct-uploads.js");
Object.defineProperty(exports, "DirectUploads", { enumerable: true, get: function () { return direct_uploads_1.DirectUploads; } });
var v2_1 = require("./v2.js");
Object.defineProperty(exports, "V2", { enumerable: true, get: function () { return v2_1.V2; } });
//# sourceMappingURL=index.js.map