// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../../resource';
import * as ProfilesAPI from './profiles';
import { ProfileGetParams, ProfileGetResponse, Profiles } from './profiles';

export class Billing extends APIResource {
  profiles: ProfilesAPI.Profiles = new ProfilesAPI.Profiles(this._client);
}

Billing.Profiles = Profiles;

export declare namespace Billing {
  export {
    Profiles as Profiles,
    type ProfileGetResponse as ProfileGetResponse,
    type ProfileGetParams as ProfileGetParams,
  };
}
