// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as SettingsAPI from "./settings/settings.mjs";
import { Settings } from "./settings/settings.mjs";
export class Hostnames extends APIResource {
    constructor() {
        super(...arguments);
        this.settings = new SettingsAPI.Settings(this._client);
    }
}
Hostnames.Settings = Settings;
//# sourceMappingURL=hostnames.mjs.map