// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
import { APIResource } from "../../resource.mjs";
import * as SmartRoutingAPI from "./smart-routing.mjs";
import { SmartRouting, } from "./smart-routing.mjs";
import * as TieredCachingAPI from "./tiered-caching.mjs";
import { TieredCaching, } from "./tiered-caching.mjs";
export class Argo extends APIResource {
    constructor() {
        super(...arguments);
        this.smartRouting = new SmartRoutingAPI.SmartRouting(this._client);
        this.tieredCaching = new TieredCachingAPI.TieredCaching(this._client);
    }
}
Argo.SmartRouting = SmartRouting;
Argo.TieredCaching = TieredCaching;
//# sourceMappingURL=argo.mjs.map