"use strict";
// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.
Object.defineProperty(exports, "__esModule", { value: true });
exports.PrebuiltPolicies = exports.PrebuiltPolicyListResponsesSinglePage = exports.CatalogSyncs = exports.CatalogSyncListResponsesSinglePage = void 0;
var catalog_syncs_1 = require("./catalog-syncs.js");
Object.defineProperty(exports, "CatalogSyncListResponsesSinglePage", { enumerable: true, get: function () { return catalog_syncs_1.CatalogSyncListResponsesSinglePage; } });
Object.defineProperty(exports, "CatalogSyncs", { enumerable: true, get: function () { return catalog_syncs_1.CatalogSyncs; } });
var prebuilt_policies_1 = require("./prebuilt-policies.js");
Object.defineProperty(exports, "PrebuiltPolicyListResponsesSinglePage", { enumerable: true, get: function () { return prebuilt_policies_1.PrebuiltPolicyListResponsesSinglePage; } });
Object.defineProperty(exports, "PrebuiltPolicies", { enumerable: true, get: function () { return prebuilt_policies_1.PrebuiltPolicies; } });
//# sourceMappingURL=index.js.map