// File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

import { APIResource } from '../../../resource';
import * as TopAPI from './top/top';
import { Top, TopDomainCategoriesParams, TopDomainCategoriesResponse } from './top/top';

export class RobotsTXT extends APIResource {
  top: TopAPI.Top = new TopAPI.Top(this._client);
}

RobotsTXT.Top = Top;

export declare namespace RobotsTXT {
  export {
    Top as Top,
    type TopDomainCategoriesResponse as TopDomainCategoriesResponse,
    type TopDomainCategoriesParams as TopDomainCategoriesParams,
  };
}
