import { APIResource } from "../../resource.js";
import * as RulesAPI from "./rules.js";
import { RuleListParams, RuleListResponse, RuleListResponsesSinglePage, RuleUpdateParams, RuleUpdateResponse, RuleUpdateResponsesSinglePage, Rules } from "./rules.js";
export declare class CloudConnector extends APIResource {
    rules: RulesAPI.Rules;
}
export declare namespace CloudConnector {
    export { Rules as Rules, type RuleUpdateResponse as RuleUpdateResponse, type RuleListResponse as RuleListResponse, RuleUpdateResponsesSinglePage as RuleUpdateResponsesSinglePage, RuleListResponsesSinglePage as RuleListResponsesSinglePage, type RuleUpdateParams as RuleUpdateParams, type RuleListParams as RuleListParams, };
}
//# sourceMappingURL=cloud-connector.d.ts.map